<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
				xmlns:xs="http://www.w3.org/2001/XMLSchema">

<!-- Raksts -->

<xsl:param name="stylesheet"/>

<!-- ======================================================== -->
<!-- Nodefinējam globālo valodu un iekļaujam valodas tulkojumu failu -->
<xsl:param name="global_lang" select="/*/@lang"/>
<xsl:include href="lang.xsl"/>

<!-- ======================================================== -->
<!-- HTML dokumenta galva -->
<xsl:template name="head">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
		<xsl:if test="title|(articleinfo|bookinfo)/title">
			<title>
				<xsl:value-of select="title|(articleinfo|bookinfo)/title"/>
			</title><xsl:text>&#x000A;</xsl:text>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$stylesheet">
				<link type="text/css" rel="StyleSheet">
					<xsl:attribute name="href" select="$stylesheet"/>
				</link>
			</xsl:when>
			<xsl:otherwise>
				<style>
					<xsl:text>.title {text-align: center;}&#x000A;</xsl:text>
					<xsl:text>.subtitle {text-align: center;}&#x000A;</xsl:text>
					<xsl:text>a.internal {text-decoration: none}&#x000A;</xsl:text>
					<xsl:text>div.footnote {font-size: small; margin-left: 0cm; margin-right: 0cm;}&#x000A;</xsl:text>
					<xsl:text>div.bibliography {margin-left: 0.5em;}&#x000A;</xsl:text>
					<xsl:text>p.footnote {margin: 0.05cm 0.2cm;}&#x000A;</xsl:text>
					<xsl:text>pre.programlisting {border-top: 2px solid; border-bottom: 2px solid; background-color: #E5E5E5; margin: 0.5cm; padding: 0.5cm;}&#x000A;</xsl:text>
					<xsl:text>li {margin-bottom: 5px;}&#x000A;</xsl:text>
					<xsl:text>.abstract {font-size: small; margin: 1cm}&#x000A;</xsl:text>
					<xsl:text>.math_block {text-align:center; margin: 8px 0cm;}&#x000A;</xsl:text>
					<xsl:text>.math_inline {}&#x000A;</xsl:text>
					<xsl:text>.monospace {font-family: monospace;}&#x000A;</xsl:text>
					
					<xsl:text>.thead {background-color: #cccccc; font-weight: bold;}&#x000A;</xsl:text>
					<xsl:text>.tfoot {background-color: #eeeeee; font-weight: bold;}&#x000A;</xsl:text>
					<xsl:text>.bottomborder {border-bottom: solid </xsl:text><xsl:value-of select="$cell.line.width"/><xsl:text>;}&#x000A;</xsl:text>
					<xsl:text>.rightborder {border-right: solid </xsl:text><xsl:value-of select="$cell.line.width"/><xsl:text>;}&#x000A;</xsl:text>
					<xsl:text>.bottomrightborder {border-bottom: solid </xsl:text><xsl:value-of select="$cell.line.width"/><xsl:text>; border-right: solid </xsl:text><xsl:value-of select="$cell.line.width"/><xsl:text>;}&#x000A;</xsl:text>
					
					<xsl:text>.definition {border: 2px solid; background-color: #f5ffd1; margin: 0.5cm; padding: 0.2cm;}&#x000A;</xsl:text>
					<xsl:text>.assignment {border: 2px solid; background-color: #dae7ef; margin: 0.5cm; padding: 0.2cm;}&#x000A;</xsl:text>
					<xsl:text>.qandaset {border: 2px solid; background-color: #fff4e0; margin: 0.5cm; padding: 0.2cm;}&#x000A;</xsl:text>
				 </style><xsl:text>&#x000A;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</head>
</xsl:template>

<xsl:template match="article|book">
	<html>
	<xsl:call-template name="head"/>
	<body>

	<!-- Virsraksts, autors, anotācija -->
	<xsl:if test="title|articleinfo/title|bookinfo/title">
		<p/>
		<div>
			<h1 class="title"><xsl:apply-templates select="title|articleinfo/title|bookinfo/title"/></h1>
			<xsl:if test="subtitle|articleinfo/subtitle|bookinfo/subtitle">
				<h2 class="subtitle"><xsl:apply-templates select="subtitle|articleinfo/subtitle|bookinfo/subtitle"/></h2>
			</xsl:if>
		</div>
	</xsl:if>
	<xsl:if test="bookinfo/authorgroup|articleinfo/authorgroup| bookinfo/author|articleinfo/author">
		<p style="text-align:center;">
			<xsl:apply-templates select="bookinfo/authorgroup|articleinfo/authorgroup| bookinfo/author|articleinfo/author"/>
		</p>
	</xsl:if>
	<xsl:if test="bookinfo/date|articleinfo/date">
		<p style="text-align:center;">
			<xsl:apply-templates select="bookinfo/date|articleinfo/date"/>
		</p>
	</xsl:if>
	<xsl:if test="abstract|bookinfo/abstract|articleinfo/abstract">
			<xsl:apply-templates select="abstract|bookinfo/abstract| articleinfo/abstract"/>
	</xsl:if>
	
	<xsl:choose>
		<xsl:when test="self::article">
			<xsl:apply-templates select="lot[not(preceding::sect1 or preceding::refentry or preceding::simplesect or preceding::section)]| calloutlist|glosslist|bibliolist|itemizedlist|orderedlist|
    segmentedlist|simplelist|variablelist|caution|important|note|
    tip|warning|literallayout|programlisting|programlistingco|
    screen|screenco|screenshot|synopsis|cmdsynopsis|funcsynopsis|
    classsynopsis|fieldsynopsis|constructorsynopsis|
    destructorsynopsis|methodsynopsis|formalpara|para|simpara|
    address|blockquote|graphic|graphicco|mediaobject|
    mediaobjectco|informalequation|informalexample|informalfigure|
    informaltable|equation|subequations|example|figure|table|msgset|procedure|
    sidebar|qandaset|task|productionset|constraintdef|anchor|
    bridgehead|remark|highlights|abstract|authorblurb|epigraph|
    indexterm|beginpage"/>
			
			<xsl:if test="(calloutlist|glosslist|bibliolist|itemizedlist|orderedlist|
    segmentedlist|simplelist|variablelist|caution|important|note|
    tip|warning|literallayout|programlisting|programlistingco|
    screen|screenco|screenshot|synopsis|cmdsynopsis|funcsynopsis|
    classsynopsis|fieldsynopsis|constructorsynopsis|
    destructorsynopsis|methodsynopsis|formalpara|para|simpara|
    address|blockquote|graphic|graphicco|mediaobject|
    mediaobjectco|informalequation|informalexample|informalfigure|
    informaltable|equation|subequations|example|figure|table|msgset|procedure|
    sidebar|qandaset|task|productionset|constraintdef|anchor|
    bridgehead|remark|highlights|abstract|authorblurb|epigraph|
    indexterm|beginpage)//footnote">
				<xsl:call-template name="generate_footnotes">
					<xsl:with-param name="footnotes" select="(calloutlist|glosslist|bibliolist|itemizedlist|orderedlist|
    segmentedlist|simplelist|variablelist|caution|important|note|
    tip|warning|literallayout|programlisting|programlistingco|
    screen|screenco|screenshot|synopsis|cmdsynopsis|funcsynopsis|
    classsynopsis|fieldsynopsis|constructorsynopsis|
    destructorsynopsis|methodsynopsis|formalpara|para|simpara|
    address|blockquote|graphic|graphicco|mediaobject|
    mediaobjectco|informalequation|informalexample|informalfigure|
    informaltable|equation|subequations|example|figure|table|msgset|procedure|
    sidebar|qandaset|task|productionset|constraintdef|anchor|
    bridgehead|remark|highlights|abstract|authorblurb|epigraph|
    indexterm|beginpage)//footnote"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:apply-templates select="sect1|refentry|simplesect|section"/>
			<xsl:apply-templates select="toc|lot[preceding::sect1 or preceding::refentry or preceding::simplesect or preceding::section] |index|glossary|bibliography|appendix|colophon|ackno"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="*[not(self::title|self::subtitle|self::articleinfo| self::bookinfo|self::abstract)]"/>
		</xsl:otherwise>
	</xsl:choose>
	</body>
	</html><xsl:text>&#x000A;</xsl:text>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Grāmatas informācija -->
<xsl:template match="bookinfo | articleinfo | tocchap"/>

<xsl:template match="title|subtitle">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="authorgroup">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="author">
	<xsl:if test="honorific">
		<xsl:value-of select="honorific"/>
		<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:value-of select="firstname"/>
	<xsl:text> </xsl:text>
	<xsl:if test="othername">
		<xsl:value-of select="othername"/>
		<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:value-of select="surname"/>
	<xsl:if test="following-sibling::author">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="date">
	<xsl:apply-templates/>
</xsl:template>

<!-- ======================================================== -->
<!-- Anotācija -->
<xsl:template match="abstract">
	<div class="abstract">
	<p style="text-align:center; font-size: medium;">
		<b>
		<xsl:choose>
			<xsl:when test="title">
				<xsl:apply-templates select="title"/>
			</xsl:when>
			<xsl:otherwise>
				<b>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'abstract'"/>
				</xsl:call-template>
				</b>
			</xsl:otherwise>
		</xsl:choose>
		</b>
	</p>
	<xsl:apply-templates select="*[not(self::title)]"/>
	<xsl:if test="descendant::footnote">
		<xsl:call-template name="generate_footnotes">
			<xsl:with-param name="footnotes" select="descendant::footnote"/>
		</xsl:call-template>
	</xsl:if>
	</div>
</xsl:template>

<!-- ======================================================== -->
<!-- Satura rādītājs un attēlu rādītājs -->
<xsl:template match="toc | lot[@role='toc']">
	<div>
		<xsl:choose>
			<xsl:when test="ancestor::book">
				<xsl:choose>
					<xsl:when test="title">
						<h1><xsl:apply-templates select="title"/></h1>
					</xsl:when>
					<xsl:otherwise>
						<h1>
						<xsl:call-template name="get_lang_string">
							<xsl:with-param name="lang" select="@lang"/>
							<xsl:with-param name="code" select="'contents'"/>
						</xsl:call-template>
						</h1>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="title">
						<h2><xsl:apply-templates select="title"/></h2>
					</xsl:when>
					<xsl:otherwise>
						<h2>
						<xsl:call-template name="get_lang_string">
							<xsl:with-param name="lang" select="@lang"/>
							<xsl:with-param name="code" select="'contents'"/>
						</xsl:call-template>
						</h2>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="generate_toc_sect">
			<xsl:with-param name="nodes" select="../preface|../part|../chapter|../sect1|../bibliography|../appendix"/>
		</xsl:call-template>
	</div>
</xsl:template>

<xsl:template name="generate_toc_sect">
	<xsl:param name="nodes"/>
	<xsl:param name="level" select="1"/>
	<ol>
		<xsl:choose>
			<xsl:when test="$level=1">
				<xsl:attribute name="style">list-style-type: none; padding-left: 0px; margin-left: 0px;</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="style">list-style-type: none;</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:for-each select="$nodes">
			<li>
				<a>
					<xsl:attribute name="href">
						<xsl:if test="ancestor-or-self::sect1">
							<xsl:for-each select="ancestor-or-self::sect1">
								<xsl:call-template name="generate_filename"/>
							</xsl:for-each>
						</xsl:if>
						<xsl:text>#</xsl:text>
						<xsl:call-template name="sect-id"/>
					</xsl:attribute>
					<xsl:attribute name="class">internal</xsl:attribute>
					<xsl:choose>
						<xsl:when test="self::bibliography">
							<xsl:choose>
								<xsl:when test="title">
									<xsl:apply-templates select="title"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="get_lang_string">
										<xsl:with-param name="lang" select="@lang"/>
										<xsl:with-param name="code" select="'bibliography'"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="./title" mode="toc"/>
						</xsl:otherwise>
					</xsl:choose>
				</a>
				<xsl:if test="not(self::appendix) and (chapter|sect1|sect2|sect3|sect4|sect5)">
					<xsl:call-template name="generate_toc_sect">
						<xsl:with-param name="nodes" select="chapter|sect1|sect2|sect3|sect4|sect5"/>
						<xsl:with-param name="level" select="level+1"/>
					</xsl:call-template>
				</xsl:if>
			</li>
		</xsl:for-each>
	</ol>
</xsl:template>

<xsl:template name="generate_filename">
	<xsl:param name="sect-id"/>
</xsl:template>

<xsl:template match="toc/title | lot[@role='toc']/title">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="lot[not(@role='toc')]">
	<div>
		<xsl:choose>
			<xsl:when test="ancestor::book">
				<xsl:choose>
					<xsl:when test="title">
						<h1><xsl:apply-templates select="title"/></h1>
					</xsl:when>
					<xsl:otherwise>
						<h1><xsl:call-template name="get_lang_string">
							<xsl:with-param name="lang" select="@lang"/>
							<xsl:with-param name="code" select="'list_of_fugures'"/>
						</xsl:call-template></h1>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="title">
						<h2><xsl:apply-templates select="title"/></h2>
					</xsl:when>
					<xsl:otherwise>
						<h2><xsl:call-template name="get_lang_string">
							<xsl:with-param name="lang" select="@lang"/>
							<xsl:with-param name="code" select="'list_of_fugures'"/>
						</xsl:call-template></h2>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		<ol style="list-style-type: none; padding-left: 0px; margin-left: 0px;">
			<xsl:for-each select="//figure">
				<li>
					<a>
						<xsl:attribute name="href">
							<xsl:text>#</xsl:text>
							<xsl:value-of select="generate-id(.)"/>
						</xsl:attribute>
						<xsl:attribute name="class">internal</xsl:attribute>
						<xsl:apply-templates select="./title" mode="lot"/>
					</a>
				</li>
			</xsl:for-each>
		</ol>
	</div>
</xsl:template>

<xsl:template name="sect-id">
	<xsl:choose>
		<xsl:when test="@id">
			<xsl:value-of select="@id"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="generate-id(.)"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Daļas un nodaļas -->
<xsl:template match="part">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="part/title" mode="toc">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::subtitle">
		<xsl:text>: </xsl:text>
		<xsl:apply-templates select="following-sibling::subtitle" mode="toc"/>
	</xsl:if>
</xsl:template>

<xsl:template match="part/title">
	<xsl:variable name="sect-id">
		<xsl:for-each select="..">
			<xsl:call-template name="sect-id"/>
		</xsl:for-each>
	</xsl:variable>
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="$sect-id"/>
		</xsl:attribute>
	</a>
	<h1>
		<xsl:apply-templates/>
		<xsl:if test="following-sibling::subtitle">
			<xsl:text>: </xsl:text>
			<xsl:apply-templates select="following-sibling::subtitle" mode="toc"/>
		</xsl:if>
	</h1>
</xsl:template>

<xsl:template match="part/subtitle"/>
<xsl:template match="part/subtitle" mode="toc">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="preface|chapter">
	<xsl:apply-templates select="*[not(self::sect1)]"/>
	<xsl:if test="descendant::footnote[not(ancestor::sect1)]">
			<xsl:call-template name="generate_footnotes">
				<xsl:with-param name="footnotes" select="descendant::footnote[not(ancestor::sect1)]"/>
			</xsl:call-template>
	</xsl:if>
	<xsl:apply-templates select="sect1"/>
</xsl:template>

<xsl:template match="preface/title" mode="toc">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="chapter/title" mode="toc">
	<xsl:if test="not(../@label='none')">
		<xsl:call-template name="get_chapter_number"/>
		<xsl:text>&#160;&#160;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="preface/title">
	<xsl:variable name="sect-id">
		<xsl:for-each select="..">
			<xsl:call-template name="sect-id"/>
		</xsl:for-each>
	</xsl:variable>
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="$sect-id"/>
		</xsl:attribute>
	</a>
	<h1>
		<xsl:apply-templates/>
	</h1>
</xsl:template>

<xsl:template match="chapter/title">
	<xsl:variable name="sect-id">
		<xsl:for-each select="..">
			<xsl:call-template name="sect-id"/>
		</xsl:for-each>
	</xsl:variable>
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="$sect-id"/>
		</xsl:attribute>
	</a>
	<h1>
		<xsl:if test="not(../@label='none')">
			<xsl:call-template name="get_chapter_number"/>
			<xsl:text>&#160;&#160;</xsl:text>
		</xsl:if>
		<xsl:apply-templates/>
	</h1>
</xsl:template>

<xsl:template name="get_chapter_number">
	<xsl:number count="chapter[not(@label='none')]" level="single"/>
</xsl:template>

<!-- ======================================================== -->
<!-- Apakšnodaļas -->

<xsl:template match="sect1 | sect2 | sect3 |sect4 | sect5">
	<xsl:apply-templates/>
	<xsl:if test="self::sect1 and descendant::footnote">
			<xsl:call-template name="generate_footnotes">
				<xsl:with-param name="footnotes" select="descendant::footnote"/>
			</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="sect1/title | sect2/title | sect3/title | sect4/title | sect5/title | section/title" mode="toc">
	<xsl:call-template name="get_sect_number"/>
	<xsl:text>&#160;&#160;</xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="sect1/title | sect2/title | sect3/title | sect4/title | sect5/title | section/title">
	<xsl:variable name="sect-id">
		<xsl:for-each select="..">
			<xsl:call-template name="sect-id"/>
		</xsl:for-each>
	</xsl:variable>
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="$sect-id"/>
		</xsl:attribute>
	</a>
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:choose>
				<xsl:when test="parent::sect1">
					<h2><xsl:if test="not(../@label='none')">
							<xsl:call-template name="get_sect_number"/>
							<xsl:text>&#160;&#160;</xsl:text>
						</xsl:if>
						<xsl:apply-templates/></h2>
				</xsl:when>
				<xsl:when test="parent::sect2">
					<h3><xsl:if test="not(../@label='none')">
							<xsl:call-template name="get_sect_number"/>
							<xsl:text>&#160;&#160;</xsl:text>
						</xsl:if>
						<xsl:apply-templates/></h3>
				</xsl:when>
				<xsl:when test="parent::sect3">
					<h4><xsl:if test="not(../@label='none')">
							<xsl:call-template name="get_sect_number"/>
							<xsl:text>&#160;&#160;</xsl:text>
						</xsl:if>
						<xsl:apply-templates/></h4>
				</xsl:when>
				<xsl:when test="parent::sect4">
					<h5><xsl:if test="not(../@label='none')">
							<xsl:call-template name="get_sect_number"/>
							<xsl:text>&#160;&#160;</xsl:text>
						</xsl:if>
						<xsl:apply-templates/></h5>
				</xsl:when>
				<xsl:when test="parent::sect5">
					<h6><xsl:if test="not(../@label='none')">
							<xsl:call-template name="get_sect_number"/>
							<xsl:text>&#160;&#160;</xsl:text>
						</xsl:if>
						<xsl:apply-templates/></h6>
				</xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="ancestor::appendix">
			<xsl:choose>
				<xsl:when test="parent::sect1">
					<h3><xsl:call-template name="get_sect_number"/>
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates/></h3>
				</xsl:when>
				<xsl:when test="parent::sect2">
					<h4><xsl:call-template name="get_sect_number"/>
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates/></h4>
				</xsl:when>
				<xsl:when test="parent::sect3">
					<h5><xsl:call-template name="get_sect_number"/>
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates/></h5>
				</xsl:when>
				<xsl:when test="parent::sect4">
					<h6><xsl:call-template name="get_sect_number"/>
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates/></h6>
				</xsl:when>
				<xsl:when test="parent::sect5">
					<h6><xsl:call-template name="get_sect_number"/>
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates/></h6>
				</xsl:when>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="get_sect_number">
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:number count="chapter[not(@label='none')] | section[not(@label='none')] | sect1[not(@label='none')] | sect2[not(@label='none')] | sect3[not(@label='none')] | sect4[not(@label='none')] | sect5[not(@label='none')]" level="multiple"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_appendix_number"/>
			<xsl:number count="section[not(@label='none')] | sect1[not(@label='none')] | sect2[not(@label='none')] | sect3[not(@label='none')] | sect4[not(@label='none')] | sect5[not(@label='none')]" level="multiple"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="para">
	<p>
		<xsl:if test="@style">
			<xsl:attribute name="style" select="@style"/>
		</xsl:if>
		<xsl:apply-templates/>
	</p>
</xsl:template>

<xsl:template match="beginpage">
</xsl:template>

<!-- ======================================================== -->
<!-- Footnote -->
<xsl:template match="footnote">
	<xsl:choose>
		<xsl:when test="ancestor::abstract">
			<xsl:call-template name="get_footnote_number">
				<xsl:with-param name="footnote-id" select="generate-id(.)"/>
				<xsl:with-param name="footnotes" select="ancestor::abstract//footnote"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="ancestor::chapter and not(ancestor::sect1)">
			<xsl:call-template name="get_footnote_number">
				<xsl:with-param name="footnote-id" select="generate-id(.)"/>
				<xsl:with-param name="footnotes" select="ancestor::chapter//footnote[not(ancestor::sect1)]"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="not(ancestor::abstract or ancestor::chapter or ancestor::sect1 or ancestor::section)">
			<xsl:call-template name="get_footnote_number">
				<xsl:with-param name="footnote-id" select="generate-id(.)"/>
				<xsl:with-param name="footnotes" select="/descendant::footnote[not(ancestor::abstract | ancestor::chapter | ancestor::sect1 | ancestor::section)]"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_footnote_number">
				<xsl:with-param name="footnote-id" select="generate-id(.)"/>
				<xsl:with-param name="footnotes" select="ancestor::sect1//footnote"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="get_footnote_number">
	<xsl:param name="footnote-id"/>
	<xsl:param name="footnotes"/>
	<xsl:for-each select="$footnotes">
		<xsl:if test="generate-id(.)=$footnote-id">
			<a>
				<xsl:attribute name="name">
					<xsl:value-of select="$footnote-id"/>
					<xsl:text>_begin</xsl:text>
				</xsl:attribute>
			</a>
			<sup><b>
			<a>
				<xsl:attribute name="href">
					<xsl:text>#</xsl:text>
					<xsl:value-of select="$footnote-id"/>
					<xsl:text>_end</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="class">internal</xsl:attribute>
				<xsl:value-of select="position()"/>
			</a>
			</b></sup>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="generate_footnotes">
	<xsl:param name="footnotes"/>
	<div class="footnote">
	<hr align="left" size="1" width="35%"/>
	<xsl:for-each select="$footnotes">
		<p class="footnote">
			<a>
				<xsl:attribute name="name">
					<xsl:value-of select="generate-id(.)"/>
					<xsl:text>_end</xsl:text>
				</xsl:attribute>
			</a>
			<sup><b>
			<a>
				<xsl:attribute name="href">
					<xsl:text>#</xsl:text>
					<xsl:value-of select="generate-id(.)"/>
					<xsl:text>_begin</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="class">internal</xsl:attribute>
				<xsl:value-of select="position()"/>
			</a>
			</b></sup>
			<xsl:text> </xsl:text>
			<xsl:apply-templates />
		</p>
	</xsl:for-each>
	</div>
</xsl:template>

<xsl:template match="footnote/para">
	<xsl:if test="preceding-sibling::para">
		<br />
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<!-- ======================================================== -->
<!-- Numurēti un nenumurēti saraksti -->
<xsl:template match="itemizedlist">
	<ul>
		<xsl:apply-templates/>
	</ul>
</xsl:template>

<xsl:template match="orderedlist">
	<ol>
		<xsl:if test="@numeration">
			<xsl:attribute name="style">
				<xsl:text>list-style-type: </xsl:text>
				<xsl:choose>
					<xsl:when test="@numeration='arabic'">
						<xsl:text>decimal</xsl:text>
					</xsl:when>
					<xsl:when test="@numeration='loweralpha'">
						<xsl:text>lower-alpha</xsl:text>
					</xsl:when>
					<xsl:when test="@numeration='lowerroman'">
						<xsl:text>lower-roman</xsl:text>
					</xsl:when>
					<xsl:when test="@numeration='upperalpha'">
						<xsl:text>upper-alpha</xsl:text>
					</xsl:when>
					<xsl:when test="@numeration='upperroman'">
						<xsl:text>upper-roman</xsl:text>
					</xsl:when>
				</xsl:choose>
				<xsl:text>;</xsl:text>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates/>
	</ol>
</xsl:template>

<xsl:template match="itemizedlist/listitem | orderedlist/listitem">
	<li>
	<xsl:apply-templates/>
	</li>
</xsl:template>

<xsl:template match="listitem/para">
	<xsl:choose>
		<xsl:when test="count(../*)>1">
			<p>
				<xsl:apply-templates/>
			</p>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Mainīgo saraksti -->

<xsl:template match="variablelist">
	<div>
	<xsl:apply-templates select="*[not(self::varlistentry)]"/>
	<ol style="list-style-type: none;">
		<xsl:apply-templates select="varlistentry"/>
	</ol>
	</div>
</xsl:template>

<xsl:template match="variablelist/title">
	<p>
		<b><xsl:apply-templates/></b>
	</p>
</xsl:template>

<xsl:template match="variablelist/titleabbrev"/>

<xsl:template match="varlistentry">
	<li>
		<xsl:apply-templates select="term"/>
		<ol style="list-style-type: none;">
			<xsl:apply-templates select="listitem"/>
		</ol>
	</li>
</xsl:template>

<xsl:template match="term">
	<xsl:if test="preceding-sibling::term">
		<xsl:text>, </xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="varlistentry/listitem">
	<li>
	<xsl:apply-templates/>
	</li>
</xsl:template>

<!-- ======================================================== -->
<!-- Uzsvari -->
<xsl:template match="emphasis">
	<xsl:choose>
		<xsl:when test="@role='bold'">
			<b><xsl:apply-templates/></b>
		</xsl:when>
		<xsl:when test="@role='bold-italica'">
			<b><i><xsl:apply-templates/></i></b>
		</xsl:when>
		<xsl:when test="ancestor::emphasis">
			<xsl:variable name="depth">
				<xsl:choose>
					<xsl:when test="ancestor::footnote">
						<xsl:value-of select="count(ancestor::emphasis) - count(ancestor::emphasis[not(ancestor::footnote)])"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="count(ancestor::emphasis)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$depth = 0">
					<i><xsl:apply-templates/></i>
				</xsl:when>
				<xsl:when test="$depth = 1">
					<span style="font-style: normal;"><b><xsl:apply-templates/></b></span>
				</xsl:when>
				<xsl:when test="$depth = 2">
					<i><xsl:apply-templates/></i>
				</xsl:when>
				<xsl:when test="$depth = 3">
					<span style="font-style: normal;">
						<xsl:apply-templates/>
					</span>
				</xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<i><xsl:apply-templates/></i>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Daži LaTeX makrosi un simboli -->
<xsl:template match="TeX">
	<xsl:text>TeX</xsl:text>
</xsl:template>

<xsl:template match="XeTeX">
	<xsl:text>XeTeX</xsl:text>
</xsl:template>

<xsl:template match="LaTeX">
	<xsl:text>LaTeX</xsl:text>
</xsl:template>

<xsl:template match="LaTeX2e">
	<xsl:text>LaTeX2e</xsl:text>
</xsl:template>

<xsl:template match="XeLaTeX">
	<xsl:text>XeLaTeX</xsl:text>
</xsl:template>

<xsl:template match="percent">
	<xsl:text>%</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Programmu piemēri un koda fragmenti -->
<xsl:template match="programlisting">
	<xsl:variable name="str">
		<xsl:apply-templates/>
	</xsl:variable>
	<pre class="programlisting">
		<xsl:value-of select="replace($str,'^&#x000A;','')"/>
	</pre>
</xsl:template>

<!-- ======================================================== -->
<!-- Attēli un video -->
<xsl:template match="figure">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<div align="center">
		<xsl:apply-templates select="*[not(self::title)]"/>
		<p>
			<xsl:if test="not(@label='none')">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'figure'"/>
					<xsl:with-param name="number">
						<xsl:call-template name="get_figure_number"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:apply-templates select="title"/>
		</p>
	</div>
</xsl:template>

<xsl:template match="figure/title">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="figure/title" mode="lot">
	<xsl:call-template name="get_figure_number"/>
	<xsl:text>.&#160;&#160;</xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="figure/titleabbrev"/>

<xsl:template name="get_figure_number">
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:number count="figure" level="any"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_appendix_number"/>
			<xsl:number count="figure" level="any" from="appendix"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="mediaobject|inlinemediaobject">
		<xsl:choose>
			<xsl:when test="descendant::videodata[(@format='SWF' or @format='YouTube' or @format='MP4' or @format='FLV') and @fileref]">
				<xsl:apply-templates select="descendant::videodata[@format='SWF' or @format='YouTube' or @format='MP4' or @format='FLV'][position()=1]"/>
			</xsl:when>
			<xsl:when test="descendant::imagedata[@role='html' and (@format='PNG' or @format='GIF' or @format='GIF87a' or @format='GIF89a' or @format='JPG' or @format='JPEG')]">
				<xsl:apply-templates select="descendant::imagedata[@role='html' and (@format='PNG' or @format='GIF' or @format='GIF87a' or @format='GIF89a' or @format='JPG' or @format='JPEG')][position()=1]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="descendant::imagedata[not(@role='print') and (@format='PNG' or @format='GIF' or @format='GIF87a' or @format='GIF89a' or @format='JPG' or @format='JPEG')][position()=1]"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="*[not(descendant::videodata) and not(descendant::imagedata)]"/>
</xsl:template>

<xsl:template match="imagedata">
	<xsl:choose>
		<xsl:when test="@align">
			<div>
				<xsl:attribute name="style">
					<xsl:text>text-align: </xsl:text>
					<xsl:value-of select="@align"/>
					<xsl:text>;</xsl:text>
				</xsl:attribute>
				<xsl:call-template name="img"/>
			</div>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="img"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="videodata">
	<xsl:choose>
		<xsl:when test="@align">
			<div>
				<xsl:attribute name="style">
					<xsl:text>text-align: </xsl:text>
					<xsl:value-of select="@align"/>
					<xsl:text>;</xsl:text>
				</xsl:attribute>
				<xsl:choose>
					<xsl:when test="@format='SWF'">
						<xsl:call-template name="embed_swf"/>
					</xsl:when>
					<xsl:when test="@format='YouTube'">
						<xsl:call-template name="embed_youtube"/>
					</xsl:when>
					<xsl:when test="@format='MP4' or @format='FLV'">
						<xsl:call-template name="embed_mp4"/>
					</xsl:when>
				</xsl:choose>
			</div>
		</xsl:when>
		<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="@format='SWF'">
						<xsl:call-template name="embed_swf"/>
					</xsl:when>
					<xsl:when test="@format='YouTube'">
						<xsl:call-template name="embed_youtube"/>
					</xsl:when>
					<xsl:when test="@format='MP4' or @format='FLV'">
						<xsl:call-template name="embed_mp4"/>
					</xsl:when>
				</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="img">
	<img>
		<xsl:attribute name="src"><xsl:value-of select="@fileref"/></xsl:attribute>
		<xsl:if test="@width">
			<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
		</xsl:if>
		<xsl:attribute name="caption"><xsl:value-of select="ancestor::figure/title|ancestor::equation/alt| ancestor::inlineequation/alt"/></xsl:attribute>
		<xsl:if test="ancestor::equation|ancestor::informalequation|ancestor::inlineequation">
			<xsl:attribute name="style">vertical-align: middle;</xsl:attribute>
		</xsl:if>
		<xsl:if test="@usemap">
			<xsl:attribute name="usemap">
				<xsl:text>#</xsl:text>
				<xsl:value-of select="@usemap"/>
			</xsl:attribute>
		</xsl:if>
	</img>
</xsl:template>

<xsl:template name="embed_swf">
	<xsl:variable name="width">
		<xsl:choose>
			<xsl:when test="@width">
				<xsl:value-of select="@width"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="640"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="height">
		<xsl:choose>
			<xsl:when test="@depth">
				<xsl:value-of select="@depth"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="400"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- Tagad konstruējam pašu objektu -->
	<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0">
		<xsl:attribute name="width">
			<xsl:value-of select="$width"/>
		</xsl:attribute>
		<xsl:attribute name="height">
			<xsl:value-of select="$height"/>
		</xsl:attribute>
		<param name="movie">
			<xsl:attribute name="value"><xsl:value-of select="@fileref"/></xsl:attribute>
		</param>
		<embed type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer">
			<xsl:attribute name="src"><xsl:value-of select="@fileref"/></xsl:attribute>
			<xsl:attribute name="width">
				<xsl:value-of select="$width"/>
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$height"/>
			</xsl:attribute>
		</embed>
	</object>
</xsl:template>

<xsl:template name="embed_youtube">
	<xsl:variable name="width">
		<xsl:choose>
			<xsl:when test="@width">
				<xsl:value-of select="@width"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="534"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="height">
		<xsl:choose>
			<xsl:when test="@depth">
				<xsl:value-of select="@depth"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="400 + 35"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- Tagad konstruējam pašu objektu -->
	<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0">
		<xsl:attribute name="width">
			<xsl:value-of select="$width"/>
		</xsl:attribute>
		<xsl:attribute name="height">
			<xsl:value-of select="$height"/>
		</xsl:attribute>
		<param name="movie">
			<xsl:attribute name="value"><xsl:value-of select="@fileref"/></xsl:attribute>
		</param>
		<param name="allowfullscreen" value="true"/>
		<embed type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" allowfullscreen="true">
			<xsl:attribute name="src"><xsl:value-of select="@fileref"/></xsl:attribute>
			<xsl:attribute name="width">
				<xsl:value-of select="$width"/>
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$height"/>
			</xsl:attribute>
		</embed>
	</object>
</xsl:template>

<xsl:template name="embed_mp4">
	<xsl:variable name="mediaplayersrc">
		<xsl:choose>
			<xsl:when test="@mediaplayerref">
				<xsl:value-of select="@mediaplayerref"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>http://www.jeroenwijering.com/embed/player.swf</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="width">
		<xsl:choose>
			<xsl:when test="@width">
				<xsl:value-of select="@width"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="640"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="height">
		<xsl:choose>
			<xsl:when test="@depth">
				<xsl:value-of select="@depth + 20"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="400"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="flashvars">
		<xsl:text>width=</xsl:text>
		<xsl:value-of select="$width"/>
		<xsl:text>&amp;</xsl:text>
		<xsl:text>height=</xsl:text>
		<xsl:value-of select="$height"/>
		<xsl:text>&amp;</xsl:text>
		<xsl:text>file=</xsl:text>
		<xsl:value-of select="@fileref"/>
		<xsl:text>&amp;searchbar=false</xsl:text>
		<!-- Ja varam, pieliekam attēlu, ko rādīt pie ielādes -->
		<xsl:if test="ancestor::mediaobject//imagedata[@role='html' and (@format='PNG' or @format='GIF' or @format='GIF87a' or @format='GIF89a' or @format='JPG' or @format='JPEG')]">
			<xsl:text>&amp;image=</xsl:text>
			<xsl:value-of select="ancestor::mediaobject//imagedata[@role='html' and (@format='PNG' or @format='GIF' or @format='GIF87a' or @format='GIF89a' or @format='JPG' or @format='JPEG')][position()=1]/@fileref"/>
		</xsl:if>
		<!-- <xsl:text>&amp;smoothing=false</xsl:text> -->
	</xsl:variable>
	
	<!-- Tagad konstruējam pašu objektu -->
	<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0">
		<xsl:attribute name="width">
			<xsl:value-of select="$width"/>
		</xsl:attribute>
		<xsl:attribute name="height">
			<xsl:value-of select="$height"/>
		</xsl:attribute>
		<param name="allowscriptaccess" value="always"/>
		<param name="allowfullscreen" value="true"/>
		<param name="movie">
			<xsl:attribute name="value">
				<xsl:value-of select="$mediaplayersrc"/>
			</xsl:attribute>
		</param>
		<param name="flashvars">
			<xsl:attribute name="value">
				<xsl:value-of select="$flashvars"/>
			</xsl:attribute>
		</param>
		<embed type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" allowscriptaccess="always" allowfullscreen="true">
			<xsl:attribute name="src">
				<xsl:value-of select="$mediaplayersrc"/>
			</xsl:attribute>
			<xsl:attribute name="width">
				<xsl:value-of select="$width"/>
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$height"/>
			</xsl:attribute>
			<xsl:attribute name="flashvars">
				<xsl:value-of select="$flashvars"/>
			</xsl:attribute>
		</embed>
	</object>
</xsl:template>

<!-- ======================================================== -->
<!-- Bibliogrāfijas -->
<xsl:include href="lu_bibliography.xsl"/>

<xsl:template match="bibliography">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<h2>
	<xsl:choose>
		<xsl:when test="title">
			<xsl:apply-templates select="title"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="@lang"/>
				<xsl:with-param name="code" select="'bibliography'"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
	</h2>
	<div class="bibliography">
		<xsl:apply-templates select="bibliodiv"/>
		<xsl:variable name="biblioutput">
			<xsl:apply-templates select="biblioentry | bibliomixed"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$bibstyle='date'">
				<xsl:apply-templates select="$biblioutput/*">
						<xsl:sort/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="$biblioutput"/>
			</xsl:otherwise>
		</xsl:choose>
	</div>
</xsl:template>

<xsl:template match="bibliography/title">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="biblioformated">
	<p>
		<a><xsl:attribute name="name" select="@name"/></a>
		<xsl:if test="$bibstyle='std' or $bibstyle='rus'">
			<xsl:text>[</xsl:text>
			<xsl:value-of select="@number"/>
			<xsl:text>]  </xsl:text>
		</xsl:if>
		<xsl:copy-of select="child::text() | child::node()"/></p>
</xsl:template>

<xsl:template match="biblioentry">
	<xsl:variable name="id">
		<xsl:choose>
			<xsl:when test="@id">
				<xsl:value-of select="@id"/>
			</xsl:when>
			<xsl:when test="descendant::abbrev">
				<xsl:apply-templates select="descendant::abbrev[1]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="generate-id(.)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<biblioformated>
		<xsl:attribute name="name" select="$id"/>
		<xsl:attribute name="number">
			<xsl:number count="biblioentry | bibliomixed" level="multiple"/>
		</xsl:attribute>
		<xsl:call-template name="form_biblioentry"/>
	</biblioformated>
</xsl:template>

<xsl:template match="emphasis" mode="biblioentry">
	<i>
		<xsl:apply-templates mode="biblioentry"/>
	</i>
</xsl:template>

<xsl:template match="citation">
	<xsl:choose>
		<xsl:when test="$bibstyle='std' or $bibstyle='rus'">
			<xsl:text>[</xsl:text>
			<xsl:apply-templates select="biblioref"/>
			<xsl:text>]</xsl:text>
		</xsl:when>
		<xsl:when test="$bibstyle='date'">
			<xsl:text>(</xsl:text>
			<xsl:apply-templates select="biblioref"/>
			<xsl:text>)</xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="biblioref">
	<xsl:choose>
		<xsl:when test="($bibstyle='std' or $bibstyle='rus') and not(parent::citation)">
			<xsl:text>[</xsl:text>
		</xsl:when>
		<xsl:when test="$bibstyle='date' and not(parent::citation)">
			<xsl:text>(</xsl:text>
		</xsl:when>
	</xsl:choose>
	<a>
		<xsl:attribute name="href">
			<xsl:text>#</xsl:text>
			<xsl:value-of select="@linkend"/>
		</xsl:attribute>
		<xsl:attribute name="class">internal</xsl:attribute>
		<xsl:call-template name="get_biblioref_number">
			<xsl:with-param name="linkend" select="@linkend"/>
		</xsl:call-template>
	</a>
	<xsl:choose>
		<xsl:when test="$bibstyle='std' or $bibstyle='rus'">
			<xsl:if test="parent::citation and following-sibling::biblioref">
				<xsl:text>,</xsl:text>
			</xsl:if>
			<xsl:if test="not(parent::citation)">
				<xsl:text>]</xsl:text>
			</xsl:if>
		</xsl:when>
		<xsl:when test="$bibstyle='date'">
			<xsl:if test="parent::citation and following-sibling::biblioref">
				<xsl:text>; </xsl:text>
			</xsl:if>
			<xsl:if test="not(parent::citation)">
				<xsl:text>)</xsl:text>
			</xsl:if>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="get_biblioref_number">
	<xsl:param name="linkend"/>
	<xsl:for-each select="//biblioentry[@id=$linkend]">
		<xsl:choose>
			<xsl:when test="$bibstyle='std' or $bibstyle='rus'">
				<xsl:number count="biblioentry | bibliomixed" level="multiple"/>
			</xsl:when>
			<xsl:when test="$bibstyle='date'">
				<xsl:call-template name="get_surname_date_citation"/>
			</xsl:when>
		</xsl:choose>
	</xsl:for-each>
</xsl:template>

<!-- ======================================================== -->
<!-- Atsauces un interneta saites -->
<xsl:template match="xref">
	<xsl:param name="ref" select="@linkend"/>
	<a>
		<xsl:call-template name="generate_href_attribute">
			<xsl:with-param name="ref" select="$ref"/>
		</xsl:call-template>
		<xsl:attribute name="class">internal</xsl:attribute>
		<xsl:choose>
			<!-- Nodaļas -->
			<xsl:when test="//chapter[@id=$ref]">
				<xsl:choose>
					<xsl:when test="//chapter[@id=$ref][@label='none']">
						<xsl:text>[</xsl:text>
						<xsl:value-of select="//chapter[@id=$ref]/@id"/>
						<xsl:text>]</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="get_lang_string">
							<xsl:with-param name="lang" select="@lang"/>
							<xsl:with-param name="code" select="'chapter_ref'"/>
							<xsl:with-param name="number">
								<xsl:for-each select="//chapter[@id=$ref]">
									<xsl:call-template name="get_chapter_number"/>
								</xsl:for-each>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- Apakšnodaļas -->
			<xsl:when test="//sect1[@id=$ref]|//sect2[@id=$ref]|//sect3[@id=$ref]| //sect4[@id=$ref]|//sect5[@id=$ref]">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'sect_ref'"/>
					<xsl:with-param name="number">
						<xsl:for-each select="//sect1[@id=$ref]|//sect2[@id=$ref]|//sect3[@id=$ref]| //sect4[@id=$ref]|//sect5[@id=$ref]">
							<xsl:call-template name="get_sect_number"/>
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<!-- Attēli -->
			<xsl:when test="//figure[@id=$ref]">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'figure_ref'"/>
					<xsl:with-param name="number">
						<xsl:for-each select="//figure[@id=$ref]">
							<xsl:call-template name="get_figure_number"/>
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<!-- Tabulas -->
			<xsl:when test="//table[@id=$ref] or //informaltable[@id=$ref]">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'table_ref'"/>
					<xsl:with-param name="number">
						<xsl:for-each select="//table[@id=$ref] | //informaltable[@id=$ref]">
							<xsl:call-template name="get_table_number"/>
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<!-- Pielikumi -->
			<xsl:when test="//appendix[@id=$ref]">
				<xsl:for-each select="//appendix[@id=$ref]">
					<xsl:call-template name="get_appendix_number"/>
				</xsl:for-each>
			</xsl:when>
			<!-- Matemātika -->
			<xsl:when test="//equation[@id=$ref] or //subequations[@id=$ref] or //latexmath[@id=$ref]">
				<xsl:text>(</xsl:text>
					<xsl:for-each select="//equation[@id=$ref] | //subequations[@id=$ref] | //latexmath[@id=$ref]">
						<xsl:call-template name="get_equation_number"/>
					</xsl:for-each>
				<xsl:text>)</xsl:text>
			</xsl:when>
			<!-- Uzdevumi -->
			<xsl:when test="//assignment[@id=$ref]">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'assignment_ref'"/>
					<xsl:with-param name="number">
						<xsl:for-each select="//assignment[@id=$ref]">
							<xsl:call-template name="get_assignment_number"/>
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<!-- Pārējie -->
			<xsl:otherwise>
			</xsl:otherwise>
		</xsl:choose>
	</a>
</xsl:template>

<xsl:template name="generate_href_attribute">
	<xsl:param name="ref"/>
	<xsl:attribute name="href">
		<xsl:text>#</xsl:text>
		<xsl:value-of select="generate-id(//*[@id=$ref])"/>
	</xsl:attribute>
</xsl:template>

<xsl:template match="ulink">
	<xsl:choose>
		<xsl:when test="@url and empty(text())">
			<a>
				<xsl:attribute name="href" select="@url"/>
				<xsl:attribute name="target">_blank</xsl:attribute>
				<xsl:value-of select="@url"/>
			</a>
		</xsl:when>
		<xsl:when test="@url and not(empty(text()))">
			<a>
				<xsl:attribute name="href" select="@url"/>
				<xsl:attribute name="target">_blank</xsl:attribute>
				<xsl:apply-templates/>
			</a>
		</xsl:when>
		<xsl:otherwise>
			<a>
				<xsl:attribute name="href">
					<xsl:apply-templates/>
				</xsl:attribute>
				<xsl:attribute name="target">_blank</xsl:attribute>
				<xsl:apply-templates/>
			</a>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Komanda un faila nosaukums -->
<xsl:template match="command | filename">
	<span class="monospace">
		<xsl:apply-templates/>
	</span>
</xsl:template>

<xsl:template match="command[ancestor::footnote] |
                     filename[ancestor::footnote] |
					 command[ancestor::title] |
                     filename[ancestor::title]">
	<span class="monospace">
		<xsl:apply-templates/>
	</span>
</xsl:template>

<!-- ======================================================== -->
<!-- Citāti un pēdiņas -->

<xsl:template match="quote">
	<xsl:text>“</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>”</xsl:text>
</xsl:template>

<xsl:template match="blockquote">
	<div style="margin: 1cm">
		<xsl:apply-templates/>
	</div>
</xsl:template>


<!-- ======================================================== -->
<!-- Pielikumi -->

<xsl:template match="appendix">
	<xsl:if test="not(preceding-sibling::appendix)">
		<xsl:call-template name="get_lang_string">
			<xsl:with-param name="lang" select="@lang"/>
			<xsl:with-param name="code" select="'appendixes'"/>
		</xsl:call-template>
	</xsl:if>
	<xsl:element name="a">
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</xsl:element>
	<h3>
		<xsl:call-template name="get_lang_string">
			<xsl:with-param name="lang" select="@lang"/>
			<xsl:with-param name="code" select="'appendix'"/>
			<xsl:with-param name="number">
				<xsl:call-template name="get_appendix_number"/>
			</xsl:with-param>
		</xsl:call-template>
	</h3>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="appendix/title" mode="toc">
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="@lang"/>
		<xsl:with-param name="code" select="'appendix_toc'"/>
		<xsl:with-param name="number">
			<xsl:call-template name="get_appendix_number"/>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="appendix/title">
	<h2><xsl:apply-templates/></h2>
</xsl:template>

<xsl:template name="get_appendix_number">
	<xsl:number count="appendix" format="A" level="single"/>
</xsl:template>

<!-- ======================================================== -->
<!-- Semantisko tagu ģenerēšana -->

<!-- Jautājumi un atbildes -->

<xsl:template match="qandaset">
	<div class="qandaset">
		<xsl:if test="title">
			<b><xsl:apply-templates select="title"/></b>
		</xsl:if>
		<xsl:apply-templates select="*[not(self::title|self::titleabbrev|self::qandaentry)]"/>
		<xsl:if test="qandaentry">
			<ol>
				<xsl:apply-templates select="qandaentry"/>
			</ol>
		</xsl:if>
	</div>
</xsl:template>

<xsl:template match="qandadiv">
	<xsl:if test="preceding-sibling::qandadiv">
		<p/>
	</xsl:if>
	<xsl:if test="title">
		<b><xsl:apply-templates select="title"/></b><br/>
	</xsl:if>
	<xsl:apply-templates select="*[not(self::title|self::titleabbrev|self::qandaentry)]"/>
	<xsl:if test="qandaentry">
		<ol>
			<xsl:apply-templates select="qandaentry"/>
		</ol>
	</xsl:if>
</xsl:template>

<xsl:template match="qandaentry">
	<xsl:choose>
		<xsl:when test="parent::answer">
			<ol>
				<xsl:call-template name="qaentry"/>
			</ol>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="qaentry"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="qaentry">
	<li>
		<xsl:apply-templates select="question"/>
		<xsl:if test="answer">
			<ol style="list-style-type: upper-alpha;">
				<xsl:apply-templates select="answer"/>
			</ol>
		</xsl:if>
	</li>
</xsl:template>

<xsl:template match="question">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="answer">
	<li>
		<xsl:apply-templates/>
	</li>
</xsl:template>

<xsl:template match="answer/para">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::para">
		<br/>
	</xsl:if>
</xsl:template>

<!-- Definīcijas -->
<xsl:template match="definition">
	<div class="definition">
		<xsl:if test="title">
			<b>
				<xsl:apply-templates select="title"/>
				<xsl:text> </xsl:text>
			</b>
		</xsl:if>
		<xsl:apply-templates select="*[not(self::title)]"/>
	</div>
</xsl:template>

<xsl:template match="definition/para">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::para">
		<br/>
	</xsl:if>
</xsl:template>

<xsl:template match="assignmentset">
	<div class="assignment">
		<xsl:if test="title">
		<div style="margin-bottom: 0.5em;">
			<b>
				<xsl:apply-templates select="title"/>
			</b>
		</div>
		</xsl:if>
		<xsl:apply-templates select="*[not(self::title)]"/>
	</div>
</xsl:template>

<!-- Uzdevumi -->
<xsl:template match="assignment">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<div>
		<xsl:if test="not(parent::assignmentset)">
			<xsl:attribute name="class" select="'assignment'"/>
		</xsl:if>
		<xsl:if test="following-sibling::assignment">
			<xsl:attribute name="style" select="'margin-bottom: 0.5em;'"/>
		</xsl:if>
		<b>
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="@lang"/>
				<xsl:with-param name="code" select="'assignment'"/>
				<xsl:with-param name="number">
					<xsl:call-template name="get_assignment_number"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="title">
				<xsl:text>. </xsl:text>
				<xsl:apply-templates select="title"/>
			</xsl:if>
		</b>
		<br/>
		<xsl:apply-templates select="*[not(self::title)]"/>
	</div>
</xsl:template>

<xsl:template match="assignment/para">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::para">
		<br/>
	</xsl:if>
</xsl:template>

<xsl:template name="get_assignment_number">
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:number count="assignment" level="any"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_appendix_number"/>
			<xsl:number count="assignment" level="any" from="appendix"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Indeksi (pagaidām neuzturam) -->

<xsl:template match="index | indexterm"/>

<!-- ======================================================== -->
<!-- Tabulas -->

<xsl:param name="table.line.width" select="'1px'"/>
<xsl:param name="cell.line.width" select="'1px'"/>

<xsl:template name="get_table_number">
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:number count="table | informaltable" level="any"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="get_appendix_number"/>
			<xsl:number count="table | informaltable" level="any" from="appendix"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="table | informaltable">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<div style="margin: 10px;">
		<xsl:attribute name="align">
			<xsl:choose>
				<xsl:when test="@align">
					<xsl:value-of select="@align"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>center</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:choose>
			<xsl:when test="thead or tfoot or tbody">
				<xsl:variable name="cols">
					<xsl:call-template name="get_cols_number"/>
				</xsl:variable>
				<table border="0">
					<xsl:call-template name="set_table_attributes">
						<xsl:with-param name="table" select="."/>
					</xsl:call-template>
					<xsl:call-template name="set_html_attributes">
						<xsl:with-param name="node" select="."/>
					</xsl:call-template>
					<xsl:apply-templates select="*[not(self::caption or self::tr)]">
						<xsl:with-param name="cols" select="$cols" tunnel="yes"/>
					</xsl:apply-templates>
					<xsl:apply-templates select="tr[1]">
						<xsl:with-param name="cols" select="$cols" tunnel="yes"/>
						<xsl:with-param name="rows" select="count(tr)" tunnel="yes"/>
					</xsl:apply-templates>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="*[not(self::title or self::titleabbrev)]"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="self::table">
			<p><xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="@lang"/>
				<xsl:with-param name="code" select="'table'"/>
				<xsl:with-param name="number">
					<xsl:call-template name="get_table_number"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:apply-templates select="title | caption"/></p>
		</xsl:if>
	</div>
</xsl:template>

<xsl:template match="col | colgroup">
	<xsl:copy-of select="."/>
</xsl:template>

<xsl:template name="set_table_attributes">
	<xsl:param name="table"/>
	<xsl:if test="$table/@width">
		<xsl:attribute name="width">
			<xsl:call-template name="width_to_pixels">
				<xsl:with-param name="width" select="$table/@width"/>
			</xsl:call-template>
		</xsl:attribute>
	</xsl:if>
	<xsl:attribute name="cellspacing">
		<xsl:choose>
			<xsl:when test="$table/@cellspacing">
				<xsl:value-of select="$table/@cellspacing"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>0</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>
	<xsl:attribute name="cellpadding">
		<xsl:choose>
			<xsl:when test="$table/@cellpadding">
				<xsl:value-of select="$table/@cellpadding"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>2</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>
	<xsl:attribute name="style">
		<!-- Teksta izkārtojums -->
		<xsl:if test="$table/tgroup/@align">
			<xsl:text>text-align: </xsl:text>
			<xsl:value-of select="$table/tgroup/@align"/>
			<xsl:text>; </xsl:text>
		</xsl:if>
		<!-- Tabulas malas -->
		<xsl:choose>
			<xsl:when test="$table/@frame = 'all' or  $table/@frame = 'border'">
				<xsl:text>border: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
			</xsl:when>
			<xsl:when test="$table/@frame = 'above' or $table/@frame = 'top'">
				<xsl:text>border-top: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
			</xsl:when>
			<xsl:when test="$table/@frame = 'below' or $table/@frame = 'bottom'">
				<xsl:text>border-bottom: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
			</xsl:when>
			<xsl:when test="$table/@frame = 'sides' or $table/@frame = 'hsides'">
				<xsl:text>border-left: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
				<xsl:text>border-right: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
			</xsl:when>
			<xsl:when test="$table/@frame = 'topbot' or $table/@frame = 'vsides'">
				<xsl:text>border-top: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
				<xsl:text>border-bottom: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
			</xsl:when>
			<xsl:when test="$table/@frame = 'none' or  $table/@frame = 'void'">
				<xsl:text>border: solid 0px; </xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="not(self::entrytbl)">
					<xsl:text>border: solid </xsl:text><xsl:value-of select="$table.line.width"/><xsl:text>; </xsl:text>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="@style">
			<xsl:value-of select="@style"/>
		</xsl:if>
	</xsl:attribute>
</xsl:template>

<xsl:template name="set_html_attributes">
	<xsl:param name="node"/>
	<xsl:for-each select="$node/(@bgcolor | @class | @frame | @label | @rules | @shortentry | @summary | @tabstyle | @title | @ondblclick | @onkeydown | @onkeyup | @onmouseup | @onmouseover | @onkeypress | @onmousedown | @onclick | @onmouseout | @onmousemove)">
		<xsl:copy/>
	</xsl:for-each>
</xsl:template>

<xsl:template match="table/title | table/caption">
	<xsl:apply-templates/>
</xsl:template>

<!-- Bloks, kas aptsrādā colspec - sākums -->
<xsl:template match="colspec">
	<xsl:param name="pos" select="1"/>
	<xsl:if test="@colnum and (@colnum &gt; $pos)">
		<xsl:call-template name="add_empty_cols">
			<xsl:with-param name="n">
				<xsl:value-of select="@colnum - $pos"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
	<col>
		<xsl:for-each select="@align|@char|@charoff">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:if test="@colwidth">
			<xsl:attribute name="width">
				<xsl:call-template name="width_to_pixels">
					<xsl:with-param name="width" select="@colwidth"/>
				</xsl:call-template>
			</xsl:attribute>
		</xsl:if>
	</col>
	<xsl:apply-templates select="following-sibling::colspec[1]">
		<xsl:with-param name="pos">
			<xsl:choose>
				<xsl:when test="@colnum">
					<xsl:value-of select="@colnum + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$pos + 1"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:with-param>
	</xsl:apply-templates>
</xsl:template>

<xsl:template name="add_empty_cols">
	<xsl:param name="n"/>
	<col/>
	<xsl:if test="$n &gt; 1">
		<xsl:call-template name="add_empty_cols">
			<xsl:with-param name="n">
				<xsl:value-of select="$n - 1"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="colgroup" mode="process_colspecs">
	<xsl:apply-templates mode="process_colspecs"/>
</xsl:template>

<xsl:template match="col" mode="process_colspecs">
	<colspec>
		<xsl:if test="parent::colgroup">
			<xsl:for-each select="parent::colgroup/@*">
				<xsl:copy/>
			</xsl:for-each>
		</xsl:if>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
	</colspec>
</xsl:template>

<xsl:template name="process_colspecs">
	<xsl:param name="colspec" select="/.."/>
	<xsl:param name="cols" tunnel="yes"/>
	<xsl:param name="pos" select="1"/>
	<xsl:if test="$colspec/@colnum and ($colspec/@colnum &gt; $pos)">
		<xsl:call-template name="add_empty_colspecs">
			<xsl:with-param name="pos" select="$pos"/>
			<xsl:with-param name="n">
				<xsl:value-of select="$colspec/@colnum - $pos"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
	<colspec>
		<xsl:for-each select="$colspec/@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:if test="not($colspec/@colnum)">
			<xsl:attribute name="colnum" select="$pos"/>
		</xsl:if>
		<xsl:if test="@colwidth">
			<xsl:attribute name="width">
				<xsl:call-template name="width_to_pixels">
					<xsl:with-param name="width" select="@colwidth"/>
				</xsl:call-template>
			</xsl:attribute>
		</xsl:if>
	</colspec>
	<xsl:choose>
		<xsl:when test="$colspec/following-sibling::colspec">
			<xsl:call-template name="process_colspecs">
				<xsl:with-param name="colspec" select="$colspec/following-sibling::colspec[1]"/>
				<xsl:with-param name="pos">
					<xsl:choose>
						<xsl:when test="$colspec/@colnum">
							<xsl:value-of select="$colspec/@colnum + 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="(not($colspec/@colnum) and $pos &lt; $cols) or ($colspec/@colnum and $colspec/@colnum &lt; $cols)">
			<xsl:call-template name="add_empty_colspecs">
				<xsl:with-param name="pos">
					<xsl:choose>
						<xsl:when test="$colspec/@colnum">
							<xsl:value-of select="$colspec/@colnum + 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="n">
					<xsl:choose>
						<xsl:when test="$colspec/@colnum">
							<xsl:value-of select="$cols - $colspec/@colnum"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$cols - $pos"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="add_empty_colspecs">
	<xsl:param name="pos"/>
	<xsl:param name="n"/>
	<xsl:param name="m" select="0"/>
	<colspec>
		<xsl:attribute name="colnum" select="$pos + $m"/>
	</colspec>
	<xsl:if test="$n &gt; 1">
		<xsl:call-template name="add_empty_colspecs">
			<xsl:with-param name="pos" select="$pos"/>
			<xsl:with-param name="n" select="$n - 1"/>
			<xsl:with-param name="m" select="$m + 1"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template name="generate-colspecs">
	<xsl:param name="colspecs" select="/.."/>
	<xsl:param name="iter" select="0"/>
	<xsl:choose>
		<xsl:when test="($iter &lt; 1) and (.. | ../..)/(col | colgroup)">
			<xsl:variable name="colspecs">
				<xsl:apply-templates select="(ancestor::table | ancestor::informaltable)/(col | colgroup)" mode="process_colspecs"/>
			</xsl:variable>
			<xsl:call-template name="generate-colspecs">
				<xsl:with-param name="colspecs">
					<xsl:call-template name="process_colspecs">
						<xsl:with-param name="colspec" select="$colspecs/colspec[1]"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="iter" select="1"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="($iter &lt; 2) and (parent::tbody[not(preceding-sibling::colspec or preceding-sibling::col or preceding-sibling::colgroup)]/../(thead|tfoot)/colspec)">
			<xsl:call-template name="generate-colspecs">
				<xsl:with-param name="colspecs">
					<xsl:call-template name="process_colspecs">
						<xsl:with-param name="colspec" select="parent::tbody[not(preceding-sibling::colspec or preceding-sibling::col or preceding-sibling::colgroup)]/../(thead|tfoot)/colspec[1]"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="iter" select="2"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="($iter &lt; 3) and (../(parent::tgroup | parent::entrytbl)/colspec)">
			<xsl:call-template name="generate-colspecs">
				<xsl:with-param name="colspecs">
					<xsl:call-template name="process_colspecs">
						<xsl:with-param name="colspec" select="../(parent::tgroup | parent::entrytbl)/colspec[1]"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="iter" select="3"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="($iter &lt; 4) and (preceding-sibling::colspec)">
			<xsl:variable name="colspecs2">
				<xsl:call-template name="process_colspecs">
					<xsl:with-param name="colspec" select="(parent::thead | parent::tfoot)/colspec[1]"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:call-template name="generate-colspecs">
				<xsl:with-param name="colspecs">
					<xsl:for-each select="$colspecs2/*">
						<xsl:variable name="colnum" select="@colnum"/>
						<colspec>
							<xsl:for-each select="$colspecs/colspec[@colnum=$colnum]/@*">
								<xsl:copy/>
							</xsl:for-each>
							<xsl:for-each select="@*">
								<xsl:copy/>
							</xsl:for-each>
						</colspec>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="iter" select="4"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:copy-of select="$colspecs"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<!-- Bloks, kas aptsrādā colspec - beigas -->


<xsl:template match="tgroup">
	<table border="0">
		<xsl:call-template name="set_table_attributes">
			<xsl:with-param name="table" select=".."/>
		</xsl:call-template>
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select=".."/>
		</xsl:call-template>
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:apply-templates select="colspec[1]"/>
		<xsl:apply-templates select="thead">
			<xsl:with-param name="cols" select="@cols" tunnel="yes"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="tbody">
			<xsl:with-param name="cols" select="@cols" tunnel="yes"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="tfoot">
			<xsl:with-param name="cols" select="@cols" tunnel="yes"/>
		</xsl:apply-templates>
	</table>
</xsl:template>

<xsl:template match="thead">
	<thead class="thead">
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:if test="@valign">
			<xsl:attribute name="style">
				<xsl:text>vertical-align: </xsl:text><xsl:value-of select="@valign"/><xsl:text>; </xsl:text>
				<xsl:if test="@style">
					<xsl:value-of select="@style"/>
				</xsl:if>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates select="colspec[1]"/>
		<xsl:apply-templates select="row[1]">
			<xsl:with-param name="rows" select="count(row)" tunnel="yes"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="tr[1]">
			<xsl:with-param name="rows" select="count(tr)" tunnel="yes"/>
		</xsl:apply-templates>
	</thead>
</xsl:template>

<xsl:template match="tfoot">
	<tfoot class="tfoot">
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:if test="@valign">
			<xsl:attribute name="style">
				<xsl:text>vertical-align: </xsl:text><xsl:value-of select="@valign"/><xsl:text>; </xsl:text>
				<xsl:if test="@style">
					<xsl:value-of select="@style"/>
				</xsl:if>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates select="colspec[1]"/>
		<xsl:apply-templates select="row[1]">
			<xsl:with-param name="rows" select="count(row)" tunnel="yes"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="tr[1]">
			<xsl:with-param name="rows" select="count(tr)" tunnel="yes"/>
		</xsl:apply-templates>
	</tfoot>
</xsl:template>

<xsl:template match="tbody">
	<tbody>
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:if test="@valign">
			<xsl:attribute name="style">
				<xsl:text>vertical-align: </xsl:text><xsl:value-of select="@valign"/><xsl:text>; </xsl:text>
				<xsl:if test="@style">
					<xsl:value-of select="@style"/>
				</xsl:if>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates select="row[1]">
			<xsl:with-param name="rows" select="count(row)" tunnel="yes"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="tr[1]">
			<xsl:with-param name="rows" select="count(tr)" tunnel="yes"/>
		</xsl:apply-templates>
	</tbody>
</xsl:template>

<xsl:template match="tr">
	<xsl:param name="row" select="1"/>
	<xsl:param name="colspecs">
		<xsl:call-template name="generate-colspecs"/>
	</xsl:param>
	<xsl:param name="empty-cells">
		<xsl:apply-templates select="*[1]" mode="build-empty-cells"/>
	</xsl:param>
	<tr>
		<xsl:if test="parent::thead">
			<xsl:attribute name="class">thead</xsl:attribute>
		</xsl:if>
		<xsl:if test="parent::tfoot">
			<xsl:attribute name="class">tfoot</xsl:attribute>
		</xsl:if>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates select="*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col" select="1"/>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="colspecs" select="$colspecs"/>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</tr>
	<xsl:apply-templates select="following-sibling::tr[1]">
		<xsl:with-param name="row" select="$row + 1"/>
		<xsl:with-param name="colspecs" select="$colspecs"/>
		<xsl:with-param name="empty-cells" select="$empty-cells"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template match="th|td" mode="build-empty-cells">
	<xsl:param name="row" select="1"/>
	<xsl:param name="col" select="1"/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:variable name="cells">
		<xsl:choose>
			<xsl:when test="@rowspan and (@rowspan &gt; 1)">
				<xsl:perform-sort>
					<xsl:sort select="@row"/>
					<xsl:sort select="@col"/>
					<xsl:copy-of select="$empty-cells/*"/>
					<xsl:call-template name="build-empty-cells">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col" select="$col"/>
						<xsl:with-param name="cell" select="."/>
					</xsl:call-template>
				</xsl:perform-sort>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$empty-cells"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="following-sibling::*">
			<xsl:apply-templates select="following-sibling::*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col">
							<xsl:choose>
								<xsl:when test="@colspan">
									<xsl:value-of select="$col + @colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$col + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:when test="not(following-sibling::*) and (../following-sibling::tr)">
			<xsl:apply-templates select="../following-sibling::tr[1]/*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row + 1"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row + 1"/>
						<xsl:with-param name="col" select="1"/>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:otherwise>
			<xsl:copy-of select="$cells"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="build-empty-cells">
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="cell"/>
	<xsl:param name="n" select="1"/>
	<xsl:choose>
		<xsl:when test="$cell/self::td or $cell/self::th">
			<xsl:if test="$n &lt; $cell/@rowspan">
				<entry>
					<xsl:attribute name="row" select="$row + 1"/>
					<xsl:attribute name="col" select="$col"/>
					<xsl:if test="$cell/@colspan">
						<xsl:copy-of select="$cell/@colspan"/>
					</xsl:if>
				</entry>
				<xsl:call-template name="build-empty-cells">
					<xsl:with-param name="row" select="$row + 1"/>
					<xsl:with-param name="col" select="$col"/>
					<xsl:with-param name="cell" select="$cell"/>
					<xsl:with-param name="n" select="$n + 1"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:when>
		<xsl:when test="$cell/self::entry or $cell/self::entrytbl">
			<xsl:if test="$n &lt;= $cell/@morerows">
				<entry>
					<xsl:attribute name="row" select="$row + 1"/>
					<xsl:attribute name="col" select="$col"/>
					<xsl:attribute name="colspan">
						<xsl:call-template name="get-colspan">
							<xsl:with-param name="cell" select="$cell"/>
						</xsl:call-template>
					</xsl:attribute>
				</entry>
				<xsl:call-template name="build-empty-cells">
					<xsl:with-param name="row" select="$row + 1"/>
					<xsl:with-param name="col" select="$col"/>
					<xsl:with-param name="cell" select="$cell"/>
					<xsl:with-param name="n" select="$n + 1"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="get-next-col">
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:choose>
		<xsl:when test="($row = 1) or not($empty-cells/entry[@row = $row])">
			<xsl:value-of select="$col"/>
		</xsl:when>
		<xsl:when test="$empty-cells/entry[@row = $row]">
			<xsl:variable name="is-cell-taken">
				<xsl:call-template name="is-cell-taken">
					<xsl:with-param name="col" select="$col"/>
					<xsl:with-param name="empty-cells">
						<xsl:copy-of select="$empty-cells/entry[@row = $row]"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$is-cell-taken = 0">
					<xsl:value-of select="$col"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="$col"/>
						<xsl:with-param name="empty-cells">
							<xsl:copy-of select="$empty-cells/entry[@row = $row]"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="is-cell-taken">
	<xsl:param name="col"/>
	<xsl:param name="empty-cells"/>
	<xsl:text>0</xsl:text>
	<xsl:for-each select="$empty-cells/*">
		<xsl:if test="($col &gt;= @col) and ($col &lt; (@col + @colspan))">
			<xsl:text>1</xsl:text>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="get-next-column">
	<xsl:param name="col"/>
	<xsl:param name="takencol" select="0"/>
	<xsl:param name="empty-cells"/>
	<xsl:choose>
		<xsl:when test="empty($empty-cells)">
			<xsl:value-of select="$col"/>
		</xsl:when>
		<xsl:when test="$takencol = 0">
			<xsl:for-each select="$empty-cells/*">
				<xsl:if test="($col &gt;= @col) and ($col &lt; (@col + @colspan))">
					<xsl:variable name="colspan">
						<xsl:choose>
							<xsl:when test="@colspan">
								<xsl:value-of select="@colspan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:number value="1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="@col + $colspan"/>
						<xsl:with-param name="empty-cells" select="$empty-cells"/>
						<xsl:with-param name="takencol" select="@col"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
			<xsl:variable name="next-cell" select="$empty-cells/entry[@col = $takencol]/following-sibling::entry[1]"/>
			<xsl:variable name="colspan">
				<xsl:choose>
					<xsl:when test="$next-cell/@colspan">
						<xsl:value-of select="$next-cell/@colspan"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:number value="1"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="($col &gt;= $next-cell/@col) and ($col &lt; ($next-cell/@col + $next-cell/@colspan))">
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="$next-cell/@col + $colspan"/>
						<xsl:with-param name="empty-cells" select="$empty-cells"/>
						<xsl:with-param name="takencol" select="$next-cell/@col"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$col"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="th|td">
	<xsl:param name="cols" tunnel="yes"/>
	<xsl:param name="rows" tunnel="yes"/>
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="colspecs" select="/.."/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:variable name="rowsep">
		<xsl:choose>
			<xsl:when test="../@rowsep">
				<xsl:value-of select="../@rowsep"/>
			</xsl:when>
			<xsl:when test="$colspecs/colspec[@colnum=$col]/@rowsep">
				<xsl:value-of select="$colspecs/colspec[@colnum=$col]/@rowsep"/>
			</xsl:when>
			<xsl:when test="../../(parent::tgroup | parent::entrytbl)/@rowsep">
				<xsl:value-of select="../../(parent::tgroup | parent::entrytbl)/@rowsep"/>
			</xsl:when>
			<xsl:when test="ancestor::table/@rowsep or ancestor::informaltable/@rowsep">
				<xsl:value-of select="(ancestor::table | ancestor::informaltable)/@rowsep"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>0</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="colsep">
		<xsl:choose>
			<xsl:when test="@colsep">
				<xsl:value-of select="@colsep"/>
			</xsl:when>
			<xsl:when test="$colspecs/colspec[@colnum=$col]/@colsep">
				<xsl:value-of select="$colspecs/colspec[@colnum=$col]/@colsep"/>
			</xsl:when>
			<xsl:when test="../../(tgroup | entrytbl)/@colsep">
				<xsl:value-of select="../../(parent::tgroup | parent::entrytbl)/@colsep"/>
			</xsl:when>
			<xsl:when test="ancestor::table/@colsep or ancestor::informaltable/@colsep">
				<xsl:value-of select="(ancestor::table | ancestor::informaltable)/@colsep"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>0</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="colspan">
		<xsl:choose>
			<xsl:when test="@colspan">
				<xsl:value-of select="@colspan"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="morerows">
		<xsl:choose>
			<xsl:when test="@rowspan">
				<xsl:value-of select="@rowspan - 1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:copy>
		<xsl:choose>
			<xsl:when test="(($rowsep != 0) and (($row + $morerows &lt; $rows) or ../parent::thead or ../parent::tbody/preceding-sibling::tfoot/(tr|row))) and (($colsep != 0) and (($col + $colspan - 1) &lt; $cols))">
				<xsl:attribute name="class" select="'bottomrightborder'"/>
			</xsl:when>
			<xsl:when test="($rowsep != 0) and (($row + $morerows &lt; $rows) or ../parent::thead or ../parent::tbody/preceding-sibling::tfoot/(tr|row))">
				<xsl:attribute name="class" select="'bottomborder'"/>
			</xsl:when>
			<xsl:when test="($colsep != 0) and (($col + $colspan - 1) &lt; $cols)">
				<xsl:attribute name="class" select="'rightborder'"/>
			</xsl:when>
		</xsl:choose>
		<xsl:for-each select="$colspecs/colspec[@colnum=$col]/(@style | @valign | @align | @char | @charoff)">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates/>
	</xsl:copy>
	<xsl:if test="following-sibling::*">
		<xsl:apply-templates select="following-sibling::*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col">
						<xsl:choose>
							<xsl:when test="@colspan">
								<xsl:value-of select="$col + @colspan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$col + 1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="colspecs" select="$colspecs"/>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</xsl:if>
</xsl:template>


<xsl:template match="row">
	<xsl:param name="row" select="1"/>
	<xsl:param name="colspecs">
		<xsl:call-template name="generate-colspecs"/>
	</xsl:param>
	<xsl:param name="empty-cells">
		<xsl:apply-templates select="*[1]" mode="build-empty-cells"/>
	</xsl:param>
	<tr>
		<xsl:if test="parent::thead">
			<xsl:attribute name="class">thead</xsl:attribute>
		</xsl:if>
		<xsl:if test="parent::tfoot">
			<xsl:attribute name="class">tfoot</xsl:attribute>
		</xsl:if>
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:if test="@valign">
			<xsl:attribute name="style">
				<xsl:text>vertical-align: </xsl:text><xsl:value-of select="@valign"/><xsl:text>; </xsl:text>
				<xsl:if test="@style">
					<xsl:value-of select="@style"/>
				</xsl:if>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates select="*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col" select="1"/>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="colspecs" select="$colspecs"/>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</tr>
	<xsl:apply-templates select="following-sibling::row[1]">
		<xsl:with-param name="row" select="$row + 1"/>
		<xsl:with-param name="colspecs" select="$colspecs"/>
		<xsl:with-param name="empty-cells" select="$empty-cells"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template match="entry | entrytbl" mode="build-empty-cells">
	<xsl:param name="row" select="1"/>
	<xsl:param name="col" select="1"/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:variable name="cells">
		<xsl:choose>
			<xsl:when test="@morerows">
				<xsl:perform-sort>
					<xsl:sort select="@row"/>
					<xsl:sort select="@col"/>
					<xsl:copy-of select="$empty-cells/*"/>
					<xsl:call-template name="build-empty-cells">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col" select="$col"/>
						<xsl:with-param name="cell" select="."/>
					</xsl:call-template>
				</xsl:perform-sort>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$empty-cells"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="following-sibling::*">
			<xsl:apply-templates select="following-sibling::*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col">
							<xsl:choose>
								<xsl:when test="@spanname or (@namest and @nameend)">
									<xsl:variable name="colspan">
										<xsl:call-template name="get-colspan"/>
									</xsl:variable>
									<xsl:value-of select="$col + $colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$col + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:when test="not(following-sibling::*) and (../following-sibling::row)">
			<xsl:apply-templates select="../following-sibling::row[1]/*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row + 1"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row + 1"/>
						<xsl:with-param name="col" select="1"/>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:otherwise>
			<xsl:copy-of select="$cells"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="entry | entrytbl">
	<xsl:param name="cols" as="xs:integer" tunnel="yes"/>
	<xsl:param name="rows" as="xs:integer" tunnel="yes"/>
	<xsl:param name="row" as="xs:integer"/>
	<xsl:param name="col" as="xs:integer"/>
	<xsl:param name="colspecs" select="/.."/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:variable name="rowsep" as="xs:integer">
		<xsl:choose>
			<xsl:when test="@rowsep">
				<xsl:value-of select="@rowsep"/>
			</xsl:when>
			<xsl:when test="../@rowsep">
				<xsl:value-of select="../@rowsep"/>
			</xsl:when>
			<xsl:when test="$colspecs/colspec[@colnum=$col]/@rowsep">
				<xsl:value-of select="$colspecs/colspec[@colnum=$col]/@rowsep"/>
			</xsl:when>
			<xsl:when test="../../(parent::tgroup | parent::entrytbl)/@rowsep">
				<xsl:value-of select="../../(parent::tgroup | parent::entrytbl)/@rowsep"/>
			</xsl:when>
			<xsl:when test="ancestor::table/@rowsep or ancestor::informaltable/@rowsep">
				<xsl:value-of select="(ancestor::table | ancestor::informaltable)/@rowsep"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="colsep" as="xs:integer">
		<xsl:choose>
			<xsl:when test="@colsep">
				<xsl:value-of select="@colsep"/>
			</xsl:when>
			<xsl:when test="$colspecs/colspec[@colnum=$col]/@colsep">
				<xsl:value-of select="$colspecs/colspec[@colnum=$col]/@colsep"/>
			</xsl:when>
			<xsl:when test="../../(parent::tgroup | parent::entrytbl)/@colsep">
				<xsl:value-of select="../../(parent::tgroup | parent::entrytbl)/@colsep"/>
			</xsl:when>
			<xsl:when test="ancestor::table/@colsep or ancestor::informaltable/@colsep">
				<xsl:value-of select="(ancestor::table | ancestor::informaltable)/@colsep"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="colspan" as="xs:integer">
		<xsl:call-template name="get-colspan"/>
	</xsl:variable>
	<xsl:variable name="morerows" as="xs:integer">
		<xsl:choose>
			<xsl:when test="@morerows">
				<xsl:value-of select="@morerows"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:number value="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<td>
		<xsl:choose>
			<xsl:when test="(($rowsep != 0) and (($row + $morerows &lt; $rows) or ../parent::thead or ../parent::tbody/preceding-sibling::tfoot/(tr|row))) and (($colsep != 0) and (($col + $colspan - 1) &lt; $cols))">
				<xsl:attribute name="class" select="'bottomrightborder'"/>
			</xsl:when>
			<xsl:when test="($rowsep != 0) and (($row + $morerows &lt; $rows) or ../parent::thead or ../parent::tbody/preceding-sibling::tfoot/(tr|row))">
				<xsl:attribute name="class" select="'bottomborder'"/>
			</xsl:when>
			<xsl:when test="($colsep != 0) and (($col + $colspan - 1) &lt; $cols)">
				<xsl:attribute name="class" select="'rightborder'"/>
			</xsl:when>
		</xsl:choose>
		<xsl:for-each select="$colspecs/colspec[@colnum=$col]/(@style | @valign | @align | @char | @charoff)">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:for-each select="@style | @valign | @align | @char | @charoff">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:if test="@spanname">
			<xsl:variable name="spanname" select="@spanname"/>
			<xsl:variable name="spanspec" select="//spanspec[@spanname=$spanname]"/>
			<xsl:if test="$spanspec/@align">
				<xsl:attribute name="align">
					<xsl:value-of select="$spanspec/@align"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="$spanspec/@char">
				<xsl:attribute name="char">
					<xsl:value-of select="$spanspec/@char"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="$spanspec/@charoff">
				<xsl:attribute name="charoff">
					<xsl:value-of select="$spanspec/@charoff"/>
				</xsl:attribute>
			</xsl:if>
		</xsl:if>
		<xsl:if test="@spanname or (@namest and @nameend)">
			<xsl:variable name="colspan">
				<xsl:call-template name="get-colspan"/>
			</xsl:variable>
			<xsl:attribute name="colspan" select="$colspan"/>
		</xsl:if>
		<xsl:if test="@morerows">
			<xsl:attribute name="rowspan">
				<xsl:value-of select="@morerows + 1"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:call-template name="set_html_attributes">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="self::entrytbl">
				<table>
					<xsl:call-template name="set_table_attributes">
						<xsl:with-param name="table" select="."/>
					</xsl:call-template>
					<xsl:call-template name="set_html_attributes">
						<xsl:with-param name="node" select="."/>
					</xsl:call-template>
					<xsl:apply-templates select="colspec[1]"/>
					<xsl:apply-templates select="thead | tbody">
						<xsl:with-param name="cols" select="@cols" tunnel="yes"/>
					</xsl:apply-templates>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</td>
	<xsl:if test="following-sibling::*">
		<xsl:apply-templates select="following-sibling::*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col">
						<xsl:choose>
							<xsl:when test="@spanname or (@namest and @nameend)">
								<xsl:variable name="colspan">
									<xsl:call-template name="get-colspan"/>
								</xsl:variable>
								<xsl:value-of select="$col + $colspan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$col + 1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="colspecs" select="$colspecs"/>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</xsl:if>
</xsl:template>

<xsl:template match="entry/para | td/para">
		<xsl:choose>
			<xsl:when test="count(../para) = 1">
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<p><xsl:apply-templates/></p>
			</xsl:otherwise>
		</xsl:choose>
</xsl:template>

<xsl:param name="dpi" select="96"/>

<xsl:template name="width_to_pixels">
	<xsl:param name="width"/>
	<xsl:choose>
		<xsl:when test="contains($width,'mm')">
			<xsl:value-of select="round(number(substring-before($width,'mm'))*$dpi div 25.4)"/>
			<xsl:text>px</xsl:text>
		</xsl:when>
		<xsl:when test="contains($width,'cm')">
			<xsl:value-of select="round(number(substring-before($width,'cm'))*$dpi div 2.54)"/>
			<xsl:text>px</xsl:text>
		</xsl:when>
		<xsl:when test="contains($width,'in')">
			<xsl:value-of select="round(number(substring-before($width,'in'))*$dpi)"/>
			<xsl:text>px</xsl:text>
		</xsl:when>
		<xsl:when test="contains($width,'pt')">
			<xsl:value-of select="round(number(substring-before($width,'pt'))*$dpi div 72)"/>
			<xsl:text>px</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$width"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="get-colspan">
	<xsl:param name="cell" select="."/>
	<xsl:choose>
		<xsl:when test="$cell/@spanname or ($cell/@namest and $cell/@nameend)">
			<xsl:variable name="namest">
				<xsl:choose>
					<xsl:when test="$cell/@spanname">
						<xsl:variable name="spanname" select="$cell/@spanname"/>
						<xsl:choose>
							<xsl:when test="ancestor::entrytbl">
								<xsl:value-of select="ancestor::entrytbl[1]/spanspec[@spanname=$spanname]/@namest"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="ancestor::tgroup/spanspec[@spanname=$spanname]/@namest"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$cell/@namest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="nameend">
				<xsl:choose>
					<xsl:when test="$cell/@spanname">
						<xsl:variable name="spanname" select="$cell/@spanname"/>
						<xsl:choose>
							<xsl:when test="ancestor::entrytbl">
								<xsl:value-of select="ancestor::entrytbl[1]/spanspec[@spanname=$spanname]/@nameend"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="ancestor::tgroup/spanspec[@spanname=$spanname]/@nameend"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$cell/@nameend"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="stnum">
				<xsl:call-template name="get-colnum">
					<xsl:with-param name="id">
						<xsl:choose>
							<xsl:when test="$cell/../(parent::thead | parent::tfoot)/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($cell/../(parent::thead | parent::tfoot)/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$cell/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($cell/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$cell/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($cell/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$cell/../../parent::tgroup/tfoot/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($cell/../../parent::tgroup/tfoot/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="generate-id($cell/(ancestor::table | ancestor::informaltable)//colspec[@colname=$namest])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="endnum">
				<xsl:call-template name="get-colnum">
					<xsl:with-param name="id">
						<xsl:choose>
							<xsl:when test="$cell/../(parent::thead | parent::tfoot)/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($cell/../(parent::thead | parent::tfoot)/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$cell/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($cell/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$cell/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($cell/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$cell/../../parent::tgroup/tfoot/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($cell/../../parent::tgroup/tfoot/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="generate-id($cell/(ancestor::table | ancestor::informaltable)//colspec[@colname=$nameend])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:value-of select="$endnum - $stnum + 1"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:number value="1"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="get-colnum">
	<xsl:param name="id"/>
	<xsl:param name="num" select="0"/>
	<xsl:choose>
		<xsl:when test="//colspec[generate-id(.)=$id]/@colnum">
			<xsl:value-of select="$num + //colspec[generate-id(.)=$id]/@colnum"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="not(//colspec[generate-id(.)=$id]/preceding-sibling::colspec)">
					<xsl:value-of select="$num + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="get-colnum">
						<xsl:with-param name="id" select="generate-id(//colspec[generate-id(.)=$id]/preceding-sibling::colspec[1])"/>
						<xsl:with-param name="num" select="$num + 1"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Bloks kolonnu skaita iegūšanai - sākums -->
<xsl:template name="get_cols_number">
	<xsl:param name="entry" select="(tbody/row[1]/*[1])|descendant::tr[not(th)][1]/td[1]"/>
	<xsl:param name="pos" select="0"/>
	<xsl:choose>
		<xsl:when test="$entry/self::entry or $entry/self::entrytbl">
			<xsl:choose>
				<xsl:when test="$entry/following-sibling::*">
					<xsl:call-template name="get_cols_number">
						<xsl:with-param name="entry" select="$entry/following-sibling::*[1]"/>
						<xsl:with-param name="pos">
							<xsl:choose>
								<xsl:when test="$entry/@spanname or ($entry/@namest and $entry/@nameend)">
									<xsl:variable name="colspan">
										<xsl:call-template name="get-colspan">
											<xsl:with-param name="cell" select="$entry"/>
										</xsl:call-template>
									</xsl:variable>
									<xsl:value-of select="$pos + $colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$pos + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$entry/@spanname or ($entry/@namest and $entry/@nameend)">
							<xsl:variable name="colspan">
								<xsl:call-template name="get-colspan">
									<xsl:with-param name="cell" select="$entry"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:value-of select="$pos + $colspan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="$entry/self::td">
			<xsl:choose>
				<xsl:when test="$entry/following-sibling::td">
					<xsl:call-template name="get_cols_number">
						<xsl:with-param name="entry" select="$entry/following-sibling::td[1]"/>
						<xsl:with-param name="pos">
							<xsl:choose>
								<xsl:when test="$entry/@colspan">
									<xsl:value-of select="$pos + $entry/@colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$pos + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$entry/@colspan">
							<xsl:value-of select="$pos + $entry/@colspan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
</xsl:template>
<!-- Bloks kolonnu skaita iegūšanai - beigas -->

</xsl:stylesheet>

