<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
				xmlns:mml="http://www.w3.org/1998/Math/MathML"
				xmlns="http://www.w3.org/1999/xhtml">

<!-- ======================================================== -->
<xsl:import href="mathml2/mmltex.xsl"/>

<xsl:output method="html" encoding="utf-8" doctype-public="//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd"/>

<!-- ======================================================== -->
<!-- Dokumenta sākums -->
<xsl:template match="/">
	<xsl:apply-templates/>
</xsl:template>

<!-- ======================================================== -->
<!-- Pievienojam kopējās transformācijas -->
<xsl:include href="html_common.xsl"/>

<!-- ======================================================== -->
<!-- Matemātika -->

<xsl:template match="equation/title | inlineequation/title"/>

<xsl:template match="equation">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<table class="math_block" cellspacing="0" cellpadding="0" width="100%" border="0">
		<tr valign="middle">
			<td width="15%">&#160;</td>
			<td>
				<xsl:choose>
					<xsl:when test="latexmath">
						<xsl:if test="(@type='align' or @type='flalign' or @type='gather') and count(latexmath)>1">
							<xsl:attribute name="rowspan" select="count(latexmath)"/>
						</xsl:if>
						<xsl:apply-templates select="latexmath"/>
					</xsl:when>
					<xsl:when test="mml:math">
						<xsl:variable name="latexmath">
							<xsl:apply-templates select="mml:math"/>
						</xsl:variable>
						<xsl:text>[tex id="</xsl:text>
						<xsl:value-of select="generate-id(.)"/>
						<xsl:text>"]</xsl:text>
						<xsl:value-of select="$latexmath"/>
						<xsl:text>[\tex]</xsl:text>
					</xsl:when>
					<xsl:when test="mediaobject">
						<xsl:apply-templates select="mediaobject"/>
					</xsl:when>
					<xsl:when test="alt">
						<span class="monospace"><xsl:copy-of select="alt"/></span>
					</xsl:when>
				</xsl:choose>
			</td>
			<td width="15%" align="left">
				<xsl:choose>
					<xsl:when test="not(@type) or @type='multline'">
						<xsl:text>(</xsl:text>
						<xsl:call-template name="get_equation_number"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="@type='align' or @type='flalign' or @type='gather'">
						<a>
							<xsl:attribute name="name">
								<xsl:value-of select="generate-id(latexmath[position()=1])"/>
							</xsl:attribute>
						</a>
						<xsl:text>(</xsl:text>
						<xsl:for-each select="latexmath[position()=1]">
							<xsl:call-template name="get_equation_number"/>
						</xsl:for-each>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>(??)</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		<xsl:if test="(@type='align' or @type='flalign' or @type='gather') and count(latexmath)>1">
			<xsl:for-each select="latexmath[position()>1]">
				<tr valign="middle">
					<td width="15%">&#160;</td>
					<td width="15%" align="left">
						<a>
							<xsl:attribute name="name">
								<xsl:value-of select="generate-id(.)"/>
							</xsl:attribute>
						</a>
						<xsl:text>(</xsl:text>
						<xsl:call-template name="get_equation_number"/>
						<xsl:text>)</xsl:text>
					</td>
				</tr>
			</xsl:for-each>
		</xsl:if>
	</table>
</xsl:template>

<xsl:template match="subequations">
	<a>
		<xsl:attribute name="name">
			<xsl:value-of select="generate-id(.)"/>
		</xsl:attribute>
	</a>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="informalequation">
	<div class="math_block">
		<xsl:choose>
			<xsl:when test="latexmath">
				<xsl:apply-templates select="latexmath"/>
			</xsl:when>
			<xsl:when test="mml:math">
				<xsl:variable name="latexmath">
					<xsl:apply-templates select="mml:math"/>
				</xsl:variable>
				<xsl:text>[tex id="</xsl:text>
				<xsl:value-of select="generate-id(.)"/>
				<xsl:text>"]</xsl:text>
				<xsl:value-of select="$latexmath"/>
				<xsl:text>[\tex]</xsl:text>
			</xsl:when>
			<xsl:when test="mediaobject">
				<xsl:apply-templates select="mediaobject"/>
			</xsl:when>
			<xsl:when test="alt">
				<span class="monospace"><xsl:copy-of select="alt"/></span>
			</xsl:when>
		</xsl:choose>
	</div>
</xsl:template>

<xsl:template match="programlisting/inlineequation">
		<xsl:copy-of select="*"/>
</xsl:template>

<xsl:template match="inlineequation">
	<span class="math_inline">
		<xsl:choose>
			<xsl:when test="latexmath">
				<xsl:apply-templates select="latexmath"/>
			</xsl:when>
			<xsl:when test="mml:math">
				<xsl:variable name="latexmath">
					<xsl:apply-templates select="mml:math"/>
				</xsl:variable>
				<xsl:text>[tex id="</xsl:text>
				<xsl:value-of select="generate-id(.)"/>
				<xsl:text>"]</xsl:text>
				<xsl:value-of select="$latexmath"/>
				<xsl:text>[\tex]</xsl:text>
			</xsl:when>
			<xsl:when test="inlinemediaobject">
				<xsl:apply-templates select="inlinemediaobject"/>
			</xsl:when>
			<xsl:when test="alt">
				<span class="monospace"><xsl:copy-of select="alt"/></span>
			</xsl:when>
		</xsl:choose>
	</span>
</xsl:template>

<xsl:template match="latexmath">
	<xsl:if test="not(parent::equation or parent::informalequation) or not(preceding-sibling::latexmath)">
		<xsl:text>[tex id="</xsl:text>
		<xsl:value-of select="generate-id(.)"/>
		<xsl:text>"]</xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="(parent::equation or parent::informalequation)">
			<xsl:if test="not(preceding-sibling::latexmath)">
				<xsl:text>\begin{</xsl:text>
				<xsl:choose>
					<xsl:when test="../@type">
						<xsl:value-of select="../@type"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>equation</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>*} </xsl:text>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\( </xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="normalize-space(.)"/>
	<xsl:if test="(parent::equation or parent::informalequation) and following-sibling::latexmath">
		<xsl:text> \\ </xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="(parent::equation or parent::informalequation)">
			<xsl:if test="not(following-sibling::latexmath)">
				<xsl:text> \end{</xsl:text>
				<xsl:choose>
					<xsl:when test="../@type">
						<xsl:value-of select="../@type"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>equation</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>*}</xsl:text>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text> \)</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="not(parent::equation or parent::informalequation) or not(following-sibling::latexmath)">
		<xsl:text>[\tex]</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="get_equation_number">
	<xsl:choose>
		<xsl:when test="not(self::equation or self::subequations[descendant::equation] or self::latexmath)">
			<xsl:text>??</xsl:text>
		</xsl:when>
		<xsl:when test="self::equation and (@type='align' or @type='flalign' or @type='gather')">
			<xsl:text>??</xsl:text>
		</xsl:when>
		<xsl:when test="self::latexmath and (not(../@type) or ../@type='multline')">
			<xsl:text>??</xsl:text>
		</xsl:when>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:choose>
				<xsl:when test="ancestor::subequations">
					<xsl:for-each select="ancestor::subequations[1]">
						<xsl:call-template name="get_equation_number"/>
					</xsl:for-each>
					<xsl:number count="equation[not(@type) or @type='multline'] | latexmath[parent::equation/@type='align' or parent::equation/@type='flalign' or parent::equation/@type='gather']" format="a" from="subequations" level="any"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:number count="equation[not(ancestor::subequations) and (not(@type) or @type='multline')] | subequations[descendant::equation] | latexmath[not(ancestor::subequations) and (parent::equation/@type='align' or parent::equation/@type='flalign' or parent::equation/@type='gather')]" level="any"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="ancestor::subequations">
					<xsl:for-each select="ancestor::subequations[1]">
						<xsl:call-template name="get_equation_number"/>
					</xsl:for-each>
					<xsl:number count="equation[not(@type) or @type='multline'] | latexmath[parent::equation/@type='align' or parent::equation/@type='flalign' or parent::equation/@type='gather']" format="a" from="subequations" level="any"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:number count="equation[not(ancestor::subequations) and (not(@type) or @type='multline')] | subequations[descendant::equation] | latexmath[not(ancestor::subequations) and (parent::equation/@type='align' or parent::equation/@type='flalign' or parent::equation/@type='gather')]" level="any" from="appendix"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
