<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
				xmlns:mml="http://www.w3.org/1998/Math/MathML"
				xmlns:xs="http://www.w3.org/2001/XMLSchema">

<!-- ======================================================== -->
<!-- Pievienojam MathML transformācijas -->
<xsl:import href="mathml2/mmltex.xsl"/>
<xsl:import href="newtbl.xsl"/>

<!-- ======================================================== -->
<!-- Globālie parametri -->
<!-- ======================================================== -->
<!-- latexmode - iespējamie parametri: xelatex (noklusējums), pdflatex -->
<xsl:param name="latexmode" select="'xelatex'"/>

<!-- Nodefinējam globālo valodu un iekļaujam valodas tulkojumu failu -->
<xsl:param name="global_lang" select="/*/@lang"/>
<xsl:include href="lang.xsl"/>

<!-- Te norādām dokumenta stilu. Stils tiks pievienots Latex -->
<!-- dokumentam. -->
<xsl:param name="style">
	<xsl:text>/usr/local/share/xml/lu/mystyle</xsl:text>
	<xsl:if test="$latexmode='xelatex'">
		<xsl:text>x</xsl:text>
	</xsl:if>
</xsl:param>
<!-- ======================================================== -->

<xsl:output method="text" encoding="utf-8"/>

<!-- ======================================================== -->
<!-- Ar šo šablonu mēs izvēlamies pareizo valodu -->
<xsl:template name="select_language">
	<xsl:param name="lang"/>
	<xsl:choose>
		<xsl:when test="$lang='lv' or $lang='lv-LV'">
			<xsl:text>\selectlanguage{latvian}</xsl:text>
		</xsl:when>
		<xsl:when test="$lang='en' or $lang='en-US' or $lang='en-GB'">
			<xsl:text>\selectlanguage{english}</xsl:text>
		</xsl:when>
		<xsl:when test="$lang='ru' or $lang='ru-RU'">
			<xsl:text>\selectlanguage{russian}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>%Unknown language code = </xsl:text>
			<xsl:value-of select="$lang" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<!-- ======================================================== -->
<!-- Dokumenta sākums -->
<xsl:template match="/">
	<xsl:apply-templates/>
</xsl:template>

<!-- LaTeX galva -->
<xsl:template name="latex_head">
	<xsl:text>\usepackage[inner=3cm,outer=2.5cm,top=2.5cm,bottom=2.5cm]{geometry}&#x000A;</xsl:text>
	<xsl:choose>
		<xsl:when test="$latexmode='xelatex'">
			<xsl:text>\usepackage{fontspec}&#x000A;</xsl:text>
			<xsl:text>\usepackage{xunicode}&#x000A;</xsl:text>
			<xsl:text>\usepackage{xltxtra}&#x000A;</xsl:text>
			<xsl:text>\usepackage{amsmath,fancyvrb}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:when test="$latexmode='pdflatex'">
			<xsl:text>\usepackage[pdftex]{graphicx}&#x000A;</xsl:text>
			<xsl:text>\usepackage[utf8]{inputenc}&#x000A;</xsl:text>
			<xsl:text>\usepackage{amsmath,amssymb,amsfonts,fancyvrb}&#x000A;</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>\usepackage[</xsl:text>
	<xsl:choose>
		<xsl:when test="$latexmode='xelatex'">
			<xsl:text>xetex,</xsl:text>
		</xsl:when>
		<xsl:when test="$latexmode='pdflatex'">
			<xsl:text>unicode,</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>colorlinks</xsl:text>
	<xsl:if test="@pdfpagemode">
		<xsl:text>,pdfpagemode=</xsl:text>
		<xsl:value-of select="@pdfpagemode"/>
	</xsl:if>
	<xsl:text>,plainpages=false,pdfpagelabels]{hyperref}&#x000A;</xsl:text>
	<xsl:text>\usepackage{</xsl:text>
	<xsl:value-of select="$style"/>
	<xsl:text>}&#x000A;&#x000A;</xsl:text>

	<xsl:if test="//index or //indexterm">
		<xsl:text>% Nepieciešams indeksiem&#x000A;</xsl:text>
		<xsl:text>\usepackage{makeidx}&#x000A;</xsl:text>
		<xsl:text>\makeindex&#x000A;</xsl:text>
	</xsl:if>

	<xsl:if test="//table or //informaltable">
		<xsl:text>% Nepieciešams newtbl tabulām&#x000A;</xsl:text>
		<xsl:text>\usepackage{longtable}&#x000A;</xsl:text>
		<xsl:text>\usepackage{multirow}&#x000A;</xsl:text>
		<xsl:text>\usepackage{calc}&#x000A;</xsl:text>
		<xsl:text>\usepackage{lscape}&#x000A;&#x000A;</xsl:text>
		
		<xsl:text>\newdimen\newtblstarfactor%&#x000A;</xsl:text>
		<xsl:text>\newdimen\newtblsparewidth%&#x000A;</xsl:text>
		<xsl:text>\newdimen\newtblcolwidth%&#x000A;&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<!-- Raksts -->
<xsl:template match="article">
	<xsl:text>\documentclass[</xsl:text>
	<xsl:choose>
		<xsl:when test="$latexmode='xelatex'">
			<xsl:text>xetex,</xsl:text>
		</xsl:when>
		<xsl:when test="$latexmode='pdflatex'">
			<xsl:text>pdftex,</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>a4paper</xsl:text>
	<xsl:choose>
		<xsl:when test="@font-size">
			<xsl:text>,</xsl:text>
			<xsl:value-of select="@font-size"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>,10pt</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="@layout='twocolumn'">
		<xsl:text>,twocolumn</xsl:text>
	</xsl:if>
	<xsl:text>]{article}&#x000A;</xsl:text>
	<xsl:call-template name="latex_head"/>

	<xsl:text>\begin{document}&#x000A;</xsl:text>
	<xsl:if test="@lang">
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:text>\end{document}&#x000A;</xsl:text>
</xsl:template>

<!-- Grāmata -->
<xsl:template match="book">
	<xsl:text>\documentclass[</xsl:text>
	<xsl:choose>
		<xsl:when test="$latexmode='xelatex'">
			<xsl:text>xetex,</xsl:text>
		</xsl:when>
		<xsl:when test="$latexmode='pdflatex'">
			<xsl:text>pdftex,</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>a4paper</xsl:text>
	<xsl:choose>
		<xsl:when test="@font-size">
			<xsl:text>,</xsl:text>
			<xsl:value-of select="@font-size"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>,10pt</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="@layout='twocolumn'">
		<xsl:text>,twocolumn</xsl:text>
	</xsl:if>
	<xsl:if test="not(@role) or @role='book'">
		<xsl:text>,openany]{book}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@role='report'">
		<xsl:text>]{report}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:call-template name="latex_head"/>

	<xsl:text>\begin{document}&#x000A;</xsl:text>
	<xsl:if test="@lang">
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:text>\end{document}&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Grāmatas informācija -->
<xsl:template match="bookinfo | articleinfo">
	<xsl:choose>
		<xsl:when test="ancestor::article/title | ancestor::book/title">
			<xsl:apply-templates select="ancestor::article/title | ancestor::book/title"  mode="maketitle"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="title" mode="maketitle"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates select="authorgroup|author|date" mode="maketitle"/>
	<xsl:text>\maketitle&#x000A;</xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="article/title | book/title">
	<xsl:if test="not(/book/bookinfo or /article/articleinfo)">
		<xsl:text>&#x000A;{\vspace*{20pt}\LARGE&#x000A;</xsl:text>
		<xsl:text>\begin{center}&#x000A;</xsl:text>
		<xsl:text>\textbf{</xsl:text><xsl:apply-templates/><xsl:text>}</xsl:text>
		<xsl:text>&#x000A;\end{center}\bigskip}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="title[parent::bookinfo or parent::articleinfo] |
					authorgroup[parent::bookinfo or parent::articleinfo] |
					author[parent::bookinfo or parent::articleinfo] |
					date[parent::bookinfo or parent::articleinfo]"/>

<xsl:template match="title" mode="maketitle">
	<xsl:text>\title{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="authorgroup" mode="maketitle">
	<xsl:text>\author{</xsl:text>
	<xsl:apply-templates mode="maketitle"/>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="author" mode="maketitle">
	<xsl:if test="not(ancestor::authorgroup)">
		<xsl:text>\author{</xsl:text>
	</xsl:if>
	<xsl:if test="honorific">
		<xsl:value-of select="honorific"/>
		<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:value-of select="firstname"/>
	<xsl:text> </xsl:text>
	<xsl:if test="othername">
		<xsl:value-of select="othername"/>
		<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:value-of select="surname"/>
	<xsl:if test="following-sibling::author">
		<xsl:text>, </xsl:text>
	</xsl:if>
	<xsl:if test="not(ancestor::authorgroup)">
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="date" mode="maketitle">
	<xsl:text>\date{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Anotācija -->
<xsl:template match="abstract">
	<xsl:if test="@lang">
		<xsl:text>&#x000A;{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="@lang"/>
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="title">
		<xsl:text>&#x000A;\renewcommand{\abstractname}{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;\begin{abstract}</xsl:text>
	<xsl:apply-templates select="*[not(self::title)]"/>
	<xsl:text>\end{abstract}</xsl:text>
	<xsl:if test="@lang">
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="abstract/title">
	<xsl:apply-templates/>
</xsl:template>

<!-- ======================================================== -->
<!-- Satura rādītājs un attēlu rādītājs -->
<xsl:template match="toc | lot[@role='toc']">
	<xsl:text>&#x000A;</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>\tableofcontents&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="toc/title | lot[@role='toc']/title">
	<xsl:text>\renewcommand{\contentsname}{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="lot[not(@role='toc')]">
	<xsl:if test="@role='figures'">
		<xsl:text>&#x000A;</xsl:text>
		<xsl:if test="title">
			<xsl:text>\renewcommand{\listfigurename}{</xsl:text>
			<xsl:apply-templates select="title"/>
			<xsl:text>}&#x000A;</xsl:text>
		</xsl:if>
		<xsl:text>\listoffigures&#x000A;&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>


<!-- ======================================================== -->
<!-- Nodaļas -->
<xsl:template match="chapter">
	<xsl:text>&#x000A;</xsl:text>
	<xsl:apply-templates/>
	<xsl:if test="@lang">
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="chapter/title | appendix/title">
	<xsl:text>{\raggedright&#x000A;</xsl:text>
	<xsl:choose>
		<xsl:when test="/article">
			<xsl:text>\section</xsl:text>
		</xsl:when>
		<xsl:when test="/book">
			<xsl:text>\chapter</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:if test="../@label='none'">
		<xsl:text>*</xsl:text>
	</xsl:if>
	<xsl:if test="following-sibling::subtitle">
		<xsl:text>[</xsl:text>
		<xsl:value-of select="."/>
		<xsl:text>]</xsl:text>
	</xsl:if>
	<xsl:text>{</xsl:text>
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::subtitle">
		<xsl:text>\\\LARGE\itshape </xsl:text>
		<xsl:apply-templates 
		   select="following-sibling::subtitle" mode="addin"/>
	</xsl:if>
	<xsl:text>}</xsl:text>
	<xsl:if test="../@id">
		<xsl:text>&#x000A;\label{</xsl:text>
		<xsl:value-of select="../@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:if test="../@label='none'">
		<xsl:text>&#x000A;</xsl:text>
		<xsl:text>\addcontentsline{toc}{chapter}{</xsl:text>
		<xsl:apply-templates/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:if test="../@lang">
		<xsl:text>{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="../@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="parent::appendix/@colwidth">
		<xsl:text>\begin{multicols}{2}\small\gfdl&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<!-- ======================================================== -->
<!-- Apakšnodaļas -->

<xsl:template match="sect1 | sect2 | sect3 | sect4 | sect5 | section">
	<xsl:text>&#x000A;</xsl:text>
	<xsl:if test="@condition">
		<xsl:value-of select="@condition"/>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="@lang">
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="sect1/title | sect2/title | sect3/title | sect4/title | sect5/title | section/title">
	<xsl:choose>
		<xsl:when test="parent::sect1[not(ancestor::appendix/parent::article)]  or parent::section[not(ancestor::section) and not(ancestor::appendix/parent::article)]">
			<xsl:call-template name="sections">
				<xsl:with-param name="sect" select="'section'"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="parent::sect2[not(ancestor::appendix/parent::article)] or parent::sect1/parent::appendix or parent::section/parent::section[not(ancestor::section) and not(ancestor::appendix/parent::article)] or parent::section/parent::appendix">
			<xsl:call-template name="sections">
				<xsl:with-param name="sect" select="'subsection'"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="parent::sect3[not(ancestor::appendix)] or parent::sect2/parent::sect1/parent::appendix or parent::section/parent::section/parent::section[not(ancestor::section) and not(ancestor::appendix)] or parent::section/parent::section/parent::appendix">
			<xsl:call-template name="sections">
				<xsl:with-param name="sect" select="'subsubsection'"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="parent::sect4[not(ancestor::appendix)] or parent::section/parent::section/parent::section/ parent::section[not(ancestor::section) and not(ancestor::appendix)]">
			<xsl:call-template name="paragraph">
				<xsl:with-param name="level" select="4"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="parent::sect5[not(ancestor::appendix)] or
						parent::section/parent::section/parent::section/
						parent::section/parent::section[not(ancestor::section) and not(ancestor::appendix)]">
			<xsl:call-template name="paragraph">
				<xsl:with-param name="level" select="5"/>
			</xsl:call-template>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="sections">
	<xsl:param name="sect"/>
	<xsl:if test="../@label and ../@label != 'none'">
		<xsl:text>\setcounter{</xsl:text><xsl:value-of select="$sect"/><xsl:text>}{</xsl:text>
		<xsl:value-of select="../@label - 1"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>{\raggedright&#x000A;</xsl:text>
	<xsl:text>\</xsl:text><xsl:value-of select="$sect"/>
	<xsl:if test="../@label='none'">
		<xsl:text>*</xsl:text>
	</xsl:if>
	<xsl:text>{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}</xsl:text>
	<xsl:if test="../@label='none'">
		<xsl:text>&#x000A;</xsl:text>
		<xsl:text>\addcontentsline{toc}{</xsl:text>
		<xsl:value-of select="$sect"/>
		<xsl:text>}{</xsl:text>
		<xsl:apply-templates/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:if test="../@id">
		<xsl:text>&#x000A;\label{</xsl:text>
		<xsl:value-of select="../@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:if test="../@lang">
		<xsl:text>{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="../@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="paragraph">
	<xsl:param name="level"/>
	<xsl:text>{\bigskip</xsl:text>
	<xsl:text>\raggedright</xsl:text>
	<xsl:choose>
		<xsl:when test="$level = 4">
			<xsl:text>\bfseries&#x000A;</xsl:text>
		</xsl:when>
		<xsl:when test="$level = 5">
			<xsl:text>\small\bfseries&#x000A;</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:apply-templates/>
	<xsl:text>&#x000A;\medskip}&#x000A;</xsl:text>
	<xsl:if test="../@lang">
		<xsl:text>{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="../@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="para">
	<xsl:text>&#x000A;</xsl:text>
	<xsl:if test="empty(text()) and not(node())">
		<xsl:text>\medskip</xsl:text>
	</xsl:if>
	<xsl:if test="@lang">
		<xsl:text>{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@role='cont'">
		<xsl:text>\noindent </xsl:text>
	</xsl:if>
	<xsl:if test="@alignment and (@alignment!='default')">
		<xsl:text>{</xsl:text>
		<xsl:choose>
			<xsl:when test="@alignment='left'">
				<xsl:text>\raggedright</xsl:text>
			</xsl:when>
			<xsl:when test="@alignment='center'">
				<xsl:text>\centering</xsl:text>
			</xsl:when>
			<xsl:when test="@alignment='right'">
				<xsl:text>\raggedleft</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}%&#x000A;</xsl:text>
	</xsl:if>

	<xsl:apply-templates/>

	<xsl:text>&#x000A;</xsl:text>
	<xsl:if test="@alignment and (@alignment!='default')">
		<xsl:text>\\}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@lang">
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="beginpage">
	<xsl:text>&#x000A;</xsl:text>
	<xsl:text>\newpage&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Matemātika -->
<xsl:template match="equation/title | inlineequation/title"/>

<xsl:template match="equation">
	<xsl:text>&#x000A;\begin{</xsl:text>
	<xsl:choose>
		<xsl:when test="@type">
			<xsl:value-of select="@type"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>equation</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:if test="not(latexmath/@id) and @id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="latexmath">
			<xsl:apply-templates select="latexmath"/>
		</xsl:when>
		<xsl:when test="mml:math">
			<xsl:apply-templates select="mml:math"/>
		</xsl:when>
		<xsl:when test="alt">
			<xsl:text>\texttt{</xsl:text>
			<xsl:copy-of select="alt"/>
			<xsl:text>}</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>&#x000A;\end{</xsl:text>
	<xsl:choose>
		<xsl:when test="@type">
			<xsl:value-of select="@type"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>equation</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="subequations">
	<xsl:text>&#x000A;\begin{subequations}</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:text>\end{subequations}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="informalequation">
	<xsl:text>&#x000A;\begin{</xsl:text>
	<xsl:choose>
		<xsl:when test="@type">
			<xsl:value-of select="@type"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>equation</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>*}&#x000A;</xsl:text>
	<xsl:if test="not(latexmath/@id) and @id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="latexmath">
			<xsl:apply-templates select="latexmath"/>
		</xsl:when>
		<xsl:when test="mml:math">
			<xsl:apply-templates select="mml:math"/>
		</xsl:when>
		<xsl:when test="alt">
			<xsl:text>\texttt{</xsl:text>
			<xsl:copy-of select="alt"/>
			<xsl:text>}</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>&#x000A;\end{</xsl:text>
	<xsl:choose>
		<xsl:when test="@type">
			<xsl:value-of select="@type"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>equation</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>*}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="programlisting/inlineequation">
	<xsl:choose>
		<xsl:when test="latexmath">
			<xsl:value-of select="latexmath"/>
		</xsl:when>
		<xsl:when test="mml:math">
			<xsl:apply-templates select="mml:math"/>
		</xsl:when>
		<xsl:when test="alt">
			<xsl:copy-of select="alt"/>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="inlineequation">
	<xsl:text>\(</xsl:text>
	<xsl:choose>
		<xsl:when test="latexmath">
			<xsl:value-of select="normalize-space(latexmath)"/>
		</xsl:when>
		<xsl:when test="mml:math">
			<xsl:apply-templates select="mml:math"/>
		</xsl:when>
		<xsl:when test="alt">
			<xsl:text>\texttt{</xsl:text>
			<xsl:copy-of select="alt"/>
			<xsl:text>}</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>\)</xsl:text>
</xsl:template>

<xsl:template match="latexmath">
	<xsl:choose>
		<xsl:when test="parent::equation or parent::informalequation">
			<xsl:value-of select="normalize-space(.)"/>
			<xsl:if test="@id">
				<xsl:text> \label{</xsl:text>
				<xsl:value-of select="@id"/>
				<xsl:text>}</xsl:text>
			</xsl:if>
			<xsl:if test="following-sibling::latexmath">
				<xsl:text> \\ </xsl:text>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\(</xsl:text>
			<xsl:value-of select="normalize-space(.)"/>
			<xsl:text>\)</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Footnote -->
<xsl:template match="footnote">
	<xsl:text>\footnote{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="footnote/para">
	<xsl:if test="preceding-sibling::para">
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<!-- ======================================================== -->
<!-- Numurēti un nenumurēti saraksti -->
<xsl:template match="itemizedlist">
	<xsl:if test="not(ancestor::itemizedlist or ancestor::orderedlist or parent::para or parent::entry)">
		<xsl:choose>
			<xsl:when test="@spacing='compact'">
				<xsl:text>\medskip&#x000A;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>\bigskip&#x000A;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="parent::para and not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>\smallskip&#x000A;</xsl:text>
			<xsl:text>{\addtolength{\leftmargini}{\parindent}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:when test="not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>{\setlength{\leftmargini}{\parindent}&#x000A;</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>\begin{itemize}&#x000A;</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@mark">
		<xsl:text>\renewcommand{</xsl:text>
		<xsl:choose>
			<xsl:when test="count(ancestor::itemizedlist)=0">
				<xsl:text>\labelitemi</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::itemizedlist)=1">
				<xsl:text>\labelitemii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::itemizedlist)=2">
				<xsl:text>\labelitemiii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::itemizedlist)=3">
				<xsl:text>\labelitemiv</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text>}{</xsl:text>
		<xsl:value-of select="@mark"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@spacing='compact'">
		<xsl:text>\setlength{\itemsep}{0pt}&#x000A;</xsl:text>
		<xsl:text>\setlength{\parsep}{0pt}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:text>\end{itemize}</xsl:text>
	<xsl:choose>
		<xsl:when test="(parent::para and not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)) or not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#x000A;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="orderedlist">
	<xsl:param name="numeration" tunnel="yes"/>
	<xsl:param name="inheritnum" tunnel="yes"/>
	<xsl:variable name="num">
		<xsl:choose>
			<xsl:when test="@numeration='arabic'">
				<xsl:text>\arabic</xsl:text>
			</xsl:when>
			<xsl:when test="@numeration='loweralpha'">
				<xsl:text>\alph</xsl:text>
			</xsl:when>
			<xsl:when test="@numeration='lowerroman'">
				<xsl:text>\roman</xsl:text>
			</xsl:when>
			<xsl:when test="@numeration='upperalpha'">
				<xsl:text>\Alph</xsl:text>
			</xsl:when>
			<xsl:when test="@numeration='upperroman'">
				<xsl:text>\Roman</xsl:text>
			</xsl:when>
			<xsl:when test="$numeration">
				<xsl:value-of select="$numeration"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="theenum">
		<xsl:if test="$inheritnum!='' and @inheritnum!='ignore'">
			<xsl:value-of select="$inheritnum"/>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="count(ancestor::orderedlist)=0">
				<xsl:text>\theenumi.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=1">
				<xsl:text>\theenumii.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=2">
				<xsl:text>\theenumiii.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=3">
				<xsl:text>\theenumiv.</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:if test="not(ancestor::itemizedlist or ancestor::orderedlist or parent::para or ancestor::entry)">
		<xsl:choose>
			<xsl:when test="@spacing='compact'">
				<xsl:text>\medskip&#x000A;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>\bigskip&#x000A;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="parent::para and not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>\smallskip&#x000A;</xsl:text>
			<xsl:text>{\addtolength{\leftmargini}{\parindent}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:when test="not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>{\setlength{\leftmargini}{\parindent}&#x000A;</xsl:text>
		</xsl:when>
	</xsl:choose>
	<xsl:text>\begin{enumerate}&#x000A;</xsl:text>
	<xsl:if test="$num != ''">
		<xsl:text>\renewcommand{</xsl:text>
		<xsl:choose>
			<xsl:when test="count(ancestor::orderedlist)=0">
				<xsl:text>\theenumi</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=1">
				<xsl:text>\theenumii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=2">
				<xsl:text>\theenumiii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=3">
				<xsl:text>\theenumiv</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text>}{</xsl:text>
		<xsl:value-of select="$num"/>
		<xsl:text>{</xsl:text>
		<xsl:choose>
			<xsl:when test="count(ancestor::orderedlist)=0">
				<xsl:text>enumi</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=1">
				<xsl:text>enumii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=2">
				<xsl:text>enumiii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=3">
				<xsl:text>enumiv</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text>}}&#x000A;</xsl:text>
		
		<xsl:text>\renewcommand{</xsl:text>
		<xsl:choose>
			<xsl:when test="count(ancestor::orderedlist)=0">
				<xsl:text>\labelenumi</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=1">
				<xsl:text>\labelenumii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=2">
				<xsl:text>\labelenumiii</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=3">
				<xsl:text>\labelenumiv</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text>}{</xsl:text>
		<xsl:value-of select="$theenum"/>
		<!-- <xsl:choose>
			<xsl:when test="count(ancestor::orderedlist)=0">
				<xsl:text>\theenumi.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=1">
				<xsl:text>\theenumii.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=2">
				<xsl:text>\theenumiii.</xsl:text>
			</xsl:when>
			<xsl:when test="count(ancestor::orderedlist)=3">
				<xsl:text>\theenumiv.</xsl:text>
			</xsl:when>
		</xsl:choose> -->
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@spacing='compact'">
		<xsl:text>\setlength{\itemsep}{0pt}&#x000A;</xsl:text>
		<xsl:text>\setlength{\parsep}{0pt}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates>
		<xsl:with-param name="numeration" tunnel="yes">
			<xsl:value-of select="$num"/>
		</xsl:with-param>
		<xsl:with-param name="inheritnum" tunnel="yes">
			<xsl:value-of select="$theenum"/>
		</xsl:with-param>
	</xsl:apply-templates>
	<xsl:text>\end{enumerate}</xsl:text>
	<xsl:choose>
		<xsl:when test="(parent::para and not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)) or not(ancestor::itemizedlist or ancestor::orderedlist or ancestor::entry)">
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#x000A;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="itemizedlist/listitem | orderedlist/listitem">
	<xsl:text>\item</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text> </xsl:text>
	<xsl:apply-templates/>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="listitem/para">
	<xsl:apply-templates/>
	<xsl:if test="position()!=last()">
	  <xsl:text>&#x000A;&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<!-- ======================================================== -->
<!-- Mainīgo saraksti -->

<xsl:template match="variablelist">
	<xsl:text>&#x000A;{</xsl:text>
	<xsl:apply-templates select="*[not(self::varlistentry)]"/>
	<xsl:text>\begin{itemize}&#x000A;</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>\renewcommand{\labelitemi}{}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelitemii}{}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelitemiii}{$\bullet$}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelitemiv}{$\circ$}&#x000A;</xsl:text>
	<xsl:if test="@spacing='compact'">
		<xsl:text>\setlength{\itemsep}{0pt}&#x000A;</xsl:text>
		<xsl:text>\setlength{\parsep}{0pt}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="varlistentry"/>
	<xsl:text>\end{itemize}</xsl:text>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="variablelist/title">
	<xsl:text>\textbf{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:text>\smallskip&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="variablelist/titleabbrev"/>

<xsl:template match="varlistentry">
	<xsl:text>\item</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text> {</xsl:text>
	<xsl:apply-templates select="term"/>
	<xsl:text>&#x000A;</xsl:text>
	<xsl:text>\begin{itemize}&#x000A;</xsl:text>
	<xsl:if test="parent::variablelist/@spacing='compact'">
		<xsl:text>\setlength{\itemsep}{0pt}&#x000A;</xsl:text>
		<xsl:text>\setlength{\parsep}{0pt}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="listitem"/>
	<xsl:text>\end{itemize}</xsl:text>
	<xsl:text>}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="term">
	<xsl:if test="preceding-sibling::term">
		<xsl:text>, </xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="varlistentry/listitem">
	<xsl:text>\item</xsl:text>
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text> </xsl:text>
	<xsl:apply-templates/>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Uzsvari -->
<xsl:template match="emphasis">
	<xsl:choose>
		<xsl:when test="@role='bold'">
			<xsl:text>\textbf{</xsl:text>
			<xsl:apply-templates/>
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:when test="@role='bold-italica'">
			<xsl:text>\emph{\textbf{</xsl:text>
			<xsl:apply-templates/>
			<xsl:text>}}</xsl:text>
		</xsl:when>
		<xsl:when test="ancestor::emphasis">
			<xsl:variable name="depth">
				<xsl:choose>
					<xsl:when test="ancestor::footnote">
						<xsl:value-of select="count(ancestor::emphasis) - count(ancestor::emphasis[not(ancestor::footnote)])"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="count(ancestor::emphasis)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$depth = 0">
					<xsl:text>\emph{</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>}</xsl:text>
				</xsl:when>
				<xsl:when test="$depth = 1">
					<xsl:text>\textnormal{\textbf{</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>}}</xsl:text>
				</xsl:when>
				<xsl:when test="$depth = 2">
					<xsl:text>\emph{</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>}</xsl:text>
				</xsl:when>
				<xsl:when test="$depth = 3">
					<xsl:text>\textnormal{</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>}</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\emph{</xsl:text>
			<xsl:apply-templates/>
			<xsl:text>}</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Daži LaTeX makrosi un simboli -->
<xsl:template match="TeX">
	<xsl:text>\TeX{}</xsl:text>
</xsl:template>

<xsl:template match="XeTeX">
	<xsl:text>\XeTeX{}</xsl:text>
</xsl:template>

<xsl:template match="LaTeX">
	<xsl:text>\LaTeX{}</xsl:text>
</xsl:template>

<xsl:template match="LaTeX2e">
	<xsl:text>\LaTeX2e{}</xsl:text>
</xsl:template>

<xsl:template match="XeLaTeX">
	<xsl:text>\XeLaTeX{}</xsl:text>
</xsl:template>

<xsl:template match="percent">
	<xsl:text>\%</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Programmu piemēri un koda fragmenti -->
<xsl:template match="programlisting">
	<xsl:text>&#x000A;&#x000A;</xsl:text>
	<xsl:text>\begin{Verbatim}[frame=lines,framerule=0.5mm,numbers=left,fontsize=</xsl:text>
	<xsl:choose>
		<xsl:when test="@font-size">
			<xsl:text>\fontsize{</xsl:text>
			<xsl:value-of select="@font-size"/>
			<xsl:text>}{</xsl:text>
			<xsl:value-of select="@font-size"/>
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\small</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>]</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>\end{Verbatim}&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Attēli -->
<xsl:template match="figure">
	<xsl:text>&#x000A;\begin{figure}</xsl:text>
	<xsl:choose>
		<xsl:when test="@floatstyle">
			<xsl:text>[</xsl:text>
			<xsl:value-of select="@floatstyle"/>
			<xsl:text>]</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>[tbp]</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>&#x000A;</xsl:text>
	<xsl:if test="not(title)">
		<xsl:if test="@id">
			<xsl:text>\label{</xsl:text>
			<xsl:value-of select="@id"/>
			<xsl:text>}&#x000A;</xsl:text>
		</xsl:if>
	</xsl:if>
	<xsl:apply-templates select="*[not(self::title)]"/>
	<xsl:text>\end{figure}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="figure/title">
	<xsl:text>&#x000A;\caption</xsl:text>
	<xsl:if test="../titleabbrev">
		<xsl:text>[</xsl:text>
		<xsl:apply-templates select="../titleabbrev" mode="capt"/>
		<xsl:text>]</xsl:text>
	</xsl:if>
	<xsl:text>{\small </xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:if test="../@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="../@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="figure/titleabbrev" mode="capt">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="figure/titleabbrev"/>

<xsl:template match="mediaobject">
	<xsl:choose>
		<xsl:when test="descendant::imagedata[@role='print' and (@format='PDF' or @format='PNG' or @format='JPG' or @format='JPEG')]">
			<xsl:apply-templates select="descendant::imagedata[@role='print' and (@format='PDF' or @format='PNG' or @format='JPG' or @format='JPEG')][position()=1]"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="descendant::imagedata[not(@role='html') and (@format='PDF' or @format='PNG' or @format='JPG' or @format='JPEG')][position()=1]"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="imagedata">
	<xsl:choose>
		<xsl:when test="@align">
			<xsl:text>\begin{</xsl:text>
			<xsl:if test="@align='left' or @align='right'">
				<xsl:text>flush</xsl:text>
			</xsl:if>
			<xsl:value-of select="@align"/>
			<xsl:text>}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\begin{center}&#x000A;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<!-- id -->
	<xsl:if test="@id">
		<xsl:text>\label{</xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<!-- Teksta platums -->
	<xsl:if test="@contentwidth">
		<xsl:text>\setlength{\fboxsep}{</xsl:text>
		<xsl:value-of select="@contentwidth"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<!-- Rāmis -->
	<xsl:if test="@frame='true'">
		<xsl:text>\fbox{</xsl:text>
	</xsl:if>
	<!-- Attēls -->
	<xsl:text>\includegraphics[</xsl:text>
	<xsl:choose>
		<!-- Platums -->
		<xsl:when test="@width">
			<xsl:text>width=</xsl:text>
			<xsl:choose>
				<xsl:when test="contains(@width,'%')">
					<xsl:value-of select="number(translate(@width,'%','')) div 100"/>
					<xsl:text>\columnwidth</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@width"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="@scale">
			<xsl:text>scale=</xsl:text>
			<xsl:value-of select="@scale"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>width=\columnwidth</xsl:text>		   
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="@scalefit">
		<xsl:text>,viewport=</xsl:text>
		<xsl:value-of select="@scalefit"/>
		<xsl:text>,clip</xsl:text>
	</xsl:if>
	<xsl:text>]{</xsl:text>
	<xsl:value-of select="@fileref"/>
	<xsl:text>}</xsl:text>
	<xsl:if test="@frame='true'">
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="ancestor::figure/title"/>
	<xsl:choose>
		<xsl:when test="@align">
			<xsl:text>&#x000A;\end{</xsl:text>
			<xsl:if test="@align='left' or @align='right'">
				<xsl:text>flush</xsl:text>
			</xsl:if>
			<xsl:value-of select="@align"/>
			<xsl:text>}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#x000A;\end{center}&#x000A;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Bibliogrāfijas -->
<xsl:include href="lu_bibliography.xsl"/>

<xsl:template match="bibliography">
	<xsl:text>&#x000A;\medskip&#x000A;</xsl:text>
	<xsl:text>\renewcommand</xsl:text>
	<xsl:choose>
		<xsl:when test="/article">
			<xsl:text>\refname</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\bibname</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>{</xsl:text>
		<xsl:choose>
			<xsl:when test="title">
				<xsl:apply-templates select="title"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'bibliography'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:text>\begin{thebibliography}{</xsl:text>
	<xsl:value-of select="count(biblioentry)"/>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:text>\addcontentsline{toc}{</xsl:text>
	<xsl:choose>
		<xsl:when test="parent::book or parent::part">
			<xsl:text>chapter</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>section</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}{</xsl:text>
	<xsl:choose>
		<xsl:when test="/article">
			<xsl:text>\refname</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\bibname</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:text>\raggedright&#x000A;</xsl:text>
	<xsl:apply-templates select="bibliodiv"/>
	<xsl:variable name="biblioutput">
		<xsl:apply-templates select="biblioentry | bibliomixed"/>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="$bibstyle='date'">
			<xsl:apply-templates select="$biblioutput/*">
					<xsl:sort/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="$biblioutput"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>\end{thebibliography}&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="bibliography/title">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="biblioformated">
	<xsl:text>\bibitem{</xsl:text>
	<xsl:value-of select="@name"/>
	<xsl:text>}&#x000A;</xsl:text>
	<xsl:if test="@lang">
		<xsl:text>{</xsl:text>
		<xsl:call-template name="select_language">
			<xsl:with-param name="lang" select="@lang"/>
		</xsl:call-template>
		<xsl:text>&#x000A;</xsl:text>
	</xsl:if>
	<xsl:copy-of select="child::text() | child::node()"/>
	<xsl:if test="@lang">
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="biblioentry">
	<xsl:variable name="id">
		<xsl:choose>
			<xsl:when test="@id">
				<xsl:value-of select="@id"/>
			</xsl:when>
			<xsl:when test="descendant::abbrev">
				<xsl:apply-templates select="descendant::abbrev[1]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="generate-id(.)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<biblioformated>
		<xsl:attribute name="name" select="$id"/>
		<xsl:if test="@lang">
			<xsl:attribute name="lang" select="@lang"/>
		</xsl:if>
		<xsl:call-template name="form_biblioentry"/>
	</biblioformated>
</xsl:template>

<xsl:template match="emphasis" mode="biblioentry">
	<xsl:text>\textit{</xsl:text>
	<xsl:apply-templates mode="biblioentry"/>
	<xsl:text>} </xsl:text>
</xsl:template>

<xsl:template match="citation">
	<xsl:text>\cite{</xsl:text>
	<xsl:apply-templates select="biblioref"/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="biblioref">
	<xsl:choose>
		<xsl:when test="ancestor::citation">
			<xsl:value-of select="@linkend"/>
			<xsl:if test="following-sibling::biblioref">
				<xsl:text>,</xsl:text>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\cite{</xsl:text>
			<xsl:value-of select="@linkend"/>
			<xsl:text>}</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Atsauces un interneta saites -->
<xsl:template match="xref">
	<xsl:param name="ref" select="@linkend"/>
	<xsl:choose>
		<xsl:when test="@role='page'">
			<xsl:text>\pageref{</xsl:text>
			<xsl:value-of select="@linkend"/>
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="//assignment[@id=$ref]">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'assignment_ref'"/>
						<xsl:with-param name="number">
							<xsl:for-each select="//assignment[@id=$ref]">
								<xsl:call-template name="get_assignment_number"/>
							</xsl:for-each>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="//equation[@id=$ref] or //subequations[@id=$ref] or //latexmath[@id=$ref]">
							<xsl:text>\eqref{</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>\ref{</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:value-of select="@linkend"/>
					<xsl:text>}</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="ulink">
	<xsl:choose>
		<xsl:when test="@url and empty(text())">
			<xsl:text>\url{</xsl:text>
			<xsl:value-of select="@url"/>
		</xsl:when>
		<xsl:when test="@url and not(empty(text()))">
			<xsl:text>\href{</xsl:text>
			<xsl:value-of select="@url"/>
			<xsl:text>}{</xsl:text>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\url{</xsl:text>
			<xsl:apply-templates/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Komanda un faila nosaukums -->
<xsl:template match="command | filename">
	<xsl:variable name="text">
		<xsl:apply-templates/>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="contains($text,'|') and contains($text,'+') and contains($text,'^')">
			<xsl:text>\texttt{</xsl:text>
				<xsl:call-template name="replaceSpecialCharacters">
					<xsl:with-param name="content" select="normalize-space($text)"/>
				</xsl:call-template>
			<xsl:text>}</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\verb</xsl:text>
			<xsl:choose>
				<xsl:when test="not(contains($text,'|'))">
					<xsl:text>|</xsl:text>
				</xsl:when>
				<xsl:when test="not(contains($text,'+'))">
					<xsl:text>+</xsl:text>
				</xsl:when>
				<xsl:when test="not(contains($text,'^'))">
					<xsl:text>^</xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:value-of select="$text"/>
			<xsl:choose>
				<xsl:when test="not(contains($text,'|'))">
					<xsl:text>|</xsl:text>
				</xsl:when>
				<xsl:when test="not(contains($text,'+'))">
					<xsl:text>+</xsl:text>
				</xsl:when>
				<xsl:when test="not(contains($text,'^'))">
					<xsl:text>^</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="command[ancestor::footnote | ancestor::title |
							 ancestor::entry] |
                     filename[ancestor::footnote | ancestor::title |
							 ancestor::entry]">
	<xsl:text>\texttt{</xsl:text>
		<xsl:variable name="text">
			<xsl:apply-templates/>
		</xsl:variable>
		<xsl:call-template name="replaceSpecialCharacters">
			<xsl:with-param name="content" select="normalize-space($text)"/>
		</xsl:call-template>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template name="replaceSpecialCharacters">
	<xsl:param name="content"/>
	<xsl:if test="string-length($content)>0">
		<xsl:choose>
			<xsl:when test="starts-with($content,'#')"><xsl:value-of select="'\#'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '#')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'$')"><xsl:value-of select="'\$'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '$')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'%')"><xsl:value-of select="'\%'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '%')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'^')"><xsl:value-of select="'\^'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '^')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'&amp;')"><xsl:value-of select="'\&amp;'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '&amp;')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'_')"><xsl:value-of select="'\_'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '_')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'{')"><xsl:value-of select="'\{'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '{')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'}')"><xsl:value-of select="'\}'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '}')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'~')"><xsl:value-of select="'\~'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '~')"/></xsl:call-template></xsl:when>
			<xsl:when test="starts-with($content,'\')"><xsl:value-of select="'$\backslash$'" /><xsl:call-template name="replaceSpecialCharacters"><xsl:with-param name="content" select="substring-after($content, '\')"/></xsl:call-template></xsl:when>

			<xsl:otherwise>
				<xsl:value-of select="substring($content,1,1)"/>
				<xsl:call-template name="replaceSpecialCharacters">
					<xsl:with-param name="content" select="substring($content, 2)"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>


<!-- ======================================================== -->
<!-- Citāti un pēdiņas -->

<xsl:template match="quote">
	<xsl:text>``</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>''</xsl:text>
</xsl:template>

<xsl:template match="blockquote">
	<xsl:text>&#x000A;\begin{quote}&#x000A;</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>&#x000A;\end{quote}&#x000A;</xsl:text>
</xsl:template>


<!-- ======================================================== -->
<!-- Pielikumi -->

<xsl:template match="appendix">
	<xsl:text>&#x000A;\newpage&#x000A;</xsl:text>
	<xsl:if test="not(preceding-sibling::appendix)">
		<xsl:text>\appendix&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Indeksi un vārdnīca -->

<xsl:template match="indexterm">
	<xsl:text>\index{</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="indexterm/primary">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="indexterm/secondary | indexterm/tertiary">
	<xsl:text>!</xsl:text>
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="indexterm/see">
	<xsl:text>|see{</xsl:text>
	<xsl:value-of select="."/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="indexterm/seealso"/>

<xsl:template match="index">
	<xsl:if test="title">
		<xsl:text>\renewcommand{\indexname}{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;\printindex&#x000A;</xsl:text>
</xsl:template>

<!-- ======================================================== -->
<!-- Semantiskie elementi -->

<!-- Jautājumi un atbildes -->

<xsl:template match="qandaset">
	<xsl:text>&#x000A;\medskip&#x000A;</xsl:text>
	<xsl:text>\begin{center}&#x000A;</xsl:text>
	<xsl:call-template name="set_qandaset_settings"/>
									<xsl:text>{&#x000A;</xsl:text>
	<xsl:text>\begin{minipage}{0.9\textwidth}\sffamily&#x000A;</xsl:text>
	<xsl:if test="title">
		<xsl:text>\textbf{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="*[not(self::title|self::titleabbrev|self::qandaentry)]"/>
	<xsl:if test="qandaentry">
		<xsl:text>\begin{enumerate}&#x000A;</xsl:text>
		<xsl:apply-templates select="qandaentry"/>
		<xsl:text>\end{enumerate}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>\end{minipage}}&#x000A;</xsl:text>
	<xsl:text>\end{center}&#x000A;&#x000A;</xsl:text>
</xsl:template>

<xsl:template name="set_qandaset_settings">
	<xsl:text>%Komandas konfigurē sarakstu simbolus&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumi}{\arabic{enumi}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumii}{\alph{enumii}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumiii}{\arabic{enumiii}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumiv}{\Alph{enumiv}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumi}{\theenumi.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumii}{\theenumii.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumiii}{\theenumiii.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumiv}{\theenumiv.}&#x000A;</xsl:text>
	
	<xsl:text>%Tiek konfigurēti kastītes parametri&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxsep}{0.8em}&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxrule}{1pt}&#x000A;</xsl:text>
	<xsl:text>\fcolorbox[rgb]{0,0,0}{1,0.96,0.88}</xsl:text>
</xsl:template>

<xsl:template match="qandadiv">
	<xsl:if test="preceding-sibling::quandadiv">
		<xsl:text>\medskip&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="title">
		<xsl:text>\textbf{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="*[not(self::title|self::titleabbrev|self::quandaentry)]"/>
	<xsl:if test="quandaentry">
		<xsl:text>\begin{enumerate}&#x000A;</xsl:text>
		<xsl:apply-templates select="qandaentry"/>
		<xsl:text>\end{enumerate}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="qandaentry">
	<xsl:choose>
		<xsl:when test="parent::answer">
			<xsl:text>\begin{enumerate}&#x000A;</xsl:text>
			<xsl:call-template name="qaentry"/>
			<xsl:text>\end{enumerate}&#x000A;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="qaentry"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="qaentry">
	<xsl:text>\item </xsl:text>
	<xsl:apply-templates select="question"/>
	<xsl:if test="answer">
		<xsl:text>\begin{enumerate}&#x000A;</xsl:text>
		<xsl:apply-templates select="answer"/>
		<xsl:text>\end{enumerate}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<xsl:template match="question">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="answer">
	<xsl:text>\item </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="question/para | answer/para">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::para">
		<xsl:text>\\</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<!-- Definīcijas -->
<xsl:template match="definition">
	<xsl:text>&#x000A;\medskip&#x000A;</xsl:text>
	<xsl:text>\begin{center}&#x000A;</xsl:text>
	<xsl:call-template name="set_definition_settings"/>
									<xsl:text>{&#x000A;</xsl:text>
	<xsl:text>\begin{minipage}{0.9\textwidth}\sffamily&#x000A;</xsl:text>
	<xsl:if test="title">
		<xsl:text>\textbf{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="*[not(self::title)]"/>
	<xsl:text>&#x000A;\end{minipage}}&#x000A;</xsl:text>
	<xsl:text>\end{center}&#x000A;&#x000A;</xsl:text>
</xsl:template>

<xsl:template name="set_definition_settings">
	<xsl:text>%Tiek konfigurēti kastītes parametri&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxsep}{0.8em}&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxrule}{1pt}&#x000A;</xsl:text>
	<xsl:text>\fcolorbox[rgb]{0,0,0}{0.96,1,0.82}</xsl:text>
</xsl:template>

<!-- Uzdevumi -->

<xsl:template match="assignmentset">
	<xsl:text>&#x000A;\medskip&#x000A;</xsl:text>
	<xsl:text>\begin{center}&#x000A;</xsl:text>
	<xsl:call-template name="set_assignment_settings"/>
									<xsl:text>{&#x000A;</xsl:text>
	<xsl:text>\begin{minipage}{0.9\textwidth}\sffamily&#x000A;</xsl:text>
	<xsl:if test="title">
		<xsl:text>\textbf{</xsl:text>
		<xsl:apply-templates select="title"/>
		<xsl:text>}\vspace{0.5em}&#x000A;&#x000A;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="assignment"/>
	<xsl:text>\end{minipage}}&#x000A;</xsl:text>
	<xsl:text>\end{center}&#x000A;&#x000A;</xsl:text>
</xsl:template>

<xsl:template name="set_assignment_settings">
	<xsl:text>%Komandas konfigurē sarakstu simbolus&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumi}{\arabic{enumi}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumii}{\alph{enumii}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumiii}{\arabic{enumiii}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\theenumiv}{\Alph{enumiv}}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumi}{\theenumi.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumii}{\theenumii.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumiii}{\theenumiii.}&#x000A;</xsl:text>
	<xsl:text>\renewcommand{\labelenumiv}{\theenumiv.}&#x000A;</xsl:text>
	
	<xsl:text>%Tiek konfigurēti kastītes parametri&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxsep}{0.8em}&#x000A;</xsl:text>
	<xsl:text>\setlength{\fboxrule}{1pt}&#x000A;</xsl:text>
	<xsl:text>\fcolorbox[rgb]{0,0,0}{0.85,0.9,0.93}</xsl:text>
</xsl:template>

<xsl:template match="assignment">
	<xsl:if test="not(parent::assignmentset)">
		<xsl:text>&#x000A;\medskip&#x000A;</xsl:text>
		<xsl:text>\begin{center}&#x000A;</xsl:text>
		<xsl:call-template name="set_assignment_settings"/>
										<xsl:text>{&#x000A;</xsl:text>
		<xsl:text>\begin{minipage}{0.9\textwidth}\sffamily&#x000A;</xsl:text>
	</xsl:if>
	<xsl:text>\textbf{</xsl:text>
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="@lang"/>
		<xsl:with-param name="code" select="'assignment'"/>
		<xsl:with-param name="number">
			<xsl:call-template name="get_assignment_number"/>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:if test="title">
		<xsl:text>. </xsl:text>
		<xsl:apply-templates select="title"/>
	</xsl:if>
	<xsl:text>}&#x000A;&#x000A;</xsl:text>
	<xsl:apply-templates select="*[not(self::title)]"/>
	<xsl:if test="following-sibling::assignment">
		<xsl:text>\vspace{0.3em}&#x000A;&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="not(parent::assignmentset)">
		<xsl:text>\end{minipage}}&#x000A;</xsl:text>
		<xsl:text>\end{center}&#x000A;&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="assignment/para">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::para">
		<xsl:text>\\</xsl:text>
	</xsl:if>
	<xsl:text>&#x000A;</xsl:text>
</xsl:template>

<xsl:template name="get_assignment_number">
	<xsl:choose>
		<xsl:when test="not(ancestor::appendix)">
			<xsl:number count="assignment" level="any"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:number count="appendix" format="A"/>
			<xsl:number count="assignment" level="any" from="appendix"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ======================================================== -->
<!-- Tabulas -->

<xsl:param name="newtbl.format.thead">\bfseries%&#x000A;</xsl:param>
<xsl:param name="newtbl.format.tbody"/>
<xsl:param name="newtbl.format.tfoot">\bfseries%&#x000A;</xsl:param>

<xsl:template match="table | informaltable">
	<xsl:if test="@orient='land'">
		<xsl:text>&#x000A;\begin{landscape}</xsl:text>
	</xsl:if>
	<xsl:if test="@float=1">
		<xsl:text>&#x000A;\begin{table}[htbp]</xsl:text>
	</xsl:if>
	<xsl:if test="@latex-font-size">
		<xsl:text>&#x000A;{\</xsl:text>
		<xsl:value-of select="@latex-font-size"/>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="thead or tfoot or (tbody or tr)">
			<xsl:variable name="tgroup">
				<table>
					<xsl:for-each select="@*">
						<xsl:copy/>
					</xsl:for-each>
					<xsl:if test="self::informaltable/@id">
						<xsl:attribute name="id" select="''"/>
					</xsl:if>
					<xsl:if test="caption">
						<title>
							<xsl:for-each select="caption/@*">
								<xsl:copy/>
							</xsl:for-each>
							<xsl:apply-templates select="caption"/>
						</title>
					</xsl:if>
					<tgroup>
						<xsl:variable name="cols">
							<xsl:call-template name="get_cols_number"/>
						</xsl:variable>
						<xsl:attribute name="cols" select="$cols"/>
						<xsl:for-each select="@rowsep | @colsep">
							<xsl:copy/>
						</xsl:for-each>
						<xsl:choose>
							<xsl:when test="thead/colspec">
								<xsl:copy-of select="thead/colspec"/>
							</xsl:when>
							<xsl:when test="tfoot/colspec">
								<xsl:copy-of select="tfoot/colspec"/>
							</xsl:when>
							<xsl:when test="descendant::tr">
								<xsl:call-template name="generate_colspecs">
									<xsl:with-param name="cols" select="$cols"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
						<xsl:choose>
							<xsl:when test="thead">
									<xsl:apply-templates select="thead"/>
							</xsl:when>
							<xsl:when test="tr/th">
								<thead>
									<xsl:apply-templates select="tr[th][1]"/>
								</thead>
							</xsl:when>
						</xsl:choose>
						<xsl:if test="tfoot">
								<xsl:apply-templates select="tfoot"/>
						</xsl:if>
						<xsl:if test="tbody">
							<xsl:apply-templates select="tbody"/>
						</xsl:if>
						<xsl:if test="tr">
							<tbody>
								<xsl:apply-templates select="tr[not(th)][1]"/>
							</tbody>
						</xsl:if>
					</tgroup>
				</table>
			</xsl:variable>
			<!-- <xsl:variable name="filename">
				<xsl:text>tgroup_</xsl:text>
				<xsl:value-of select="generate-id(.)"/>
				<xsl:text>.txt</xsl:text>
			</xsl:variable>
			<xsl:result-document href="{$filename}" method="xml" indent="yes">
				<xsl:copy-of select="$tgroup"/>
			</xsl:result-document> -->
			<xsl:apply-templates select="$tgroup/table/tgroup" mode="newtbl"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#x000A;\begingroup%</xsl:text>
			<xsl:apply-templates select="*[not(self::title or self::titleabbrev)]"/>
			<xsl:text>\endgroup%&#x000A;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="@latex-font-size">
		<xsl:text>}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@float=1">
		<xsl:text>\end{table}&#x000A;</xsl:text>
	</xsl:if>
	<xsl:if test="@orient='land'">
		<xsl:text>\end{landscape}&#x000A;</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="generate_colspecs">
	<xsl:param name="cols"/>
	<xsl:param name="n" select="0"/>
	<xsl:param name="iscol" select="0"/>
	<xsl:param name="htmlcols"/>
	<xsl:choose>
		<xsl:when test="($n = 0) and ($iscol = 0) and (col | colgroup)">
			<xsl:variable name="htmlcols">
				<xsl:apply-templates select="col | colgroup"/>
			</xsl:variable>
			<xsl:call-template name="generate_colspecs">
				<xsl:with-param name="cols" select="$cols"/>
				<xsl:with-param name="n" select="0"/>
				<xsl:with-param name="iscol" select="1"/>
				<xsl:with-param name="htmlcols" select="$htmlcols"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$n &lt; $cols">
			<colspec>
				<xsl:if test="$iscol = 1">
					<xsl:for-each select="$htmlcols/col[$n + 1]/@*">
						<xsl:copy/>
					</xsl:for-each>
				</xsl:if>
				<xsl:attribute name="colname">
					<xsl:text>col</xsl:text>
					<xsl:value-of select="$n + 1"/>
				</xsl:attribute>
				<xsl:attribute name="colnum" select="$n + 1"/>
			</colspec>
			<xsl:call-template name="generate_colspecs">
				<xsl:with-param name="cols" select="$cols"/>
				<xsl:with-param name="n" select="$n + 1"/>
				<xsl:with-param name="iscol" select="$iscol"/>
				<xsl:with-param name="htmlcols" select="$htmlcols"/>
			</xsl:call-template>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="colgroup">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="col">
	<col>
		<xsl:if test="parent::colgroup">
			<xsl:for-each select="parent::colgroup/@*">
				<xsl:copy/>
			</xsl:for-each>
		</xsl:if>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
	</col>
</xsl:template>

<xsl:template match="table/title | table/titleabbrev | table/caption">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="tgroup">
	<xsl:variable name="tgroup">
		<table>
			<xsl:for-each select="../@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:if test="parent::informaltable/@id">
				<xsl:attribute name="id" select="''"/>
			</xsl:if>
			<xsl:if test="not(preceding-sibling::tgroup)">
				<xsl:if test="../title">
					<xsl:copy-of select="../title"/>
				</xsl:if>
				<xsl:if test="../titleabbrev">
					<xsl:copy-of select="../titleabbrev"/>
				</xsl:if>
			</xsl:if>
			<tgroup>
				<xsl:for-each select="@*">
					<xsl:copy/>
				</xsl:for-each>
				<xsl:choose>
					<xsl:when test="colspec | spanspec">
						<xsl:apply-templates select="colspec | spanspec"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="generate_colspecs">
							<xsl:with-param name="cols" select="@cols"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:apply-templates select="thead | tfoot | tbody"/>
			</tgroup>
		</table>
	</xsl:variable>
	<xsl:if test="preceding-sibling::tgroup">
		<xsl:text>\addtocounter{table}{-1}</xsl:text>
	</xsl:if>
	<xsl:apply-templates mode="newtbl" select="$tgroup/table/tgroup"/>
</xsl:template>

<xsl:template match="entry/para">
	<xsl:variable name="output">
		<xsl:apply-templates/>
	</xsl:variable>
	<xsl:value-of select="normalize-space($output)"/>
	<xsl:choose>
		<xsl:when test="empty(text())">
			<xsl:text>\medskip&#x000A;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="position()!=last()">
				<xsl:text>\\&#x000A;</xsl:text>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="colspec | spanspec">
	<xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="thead">
	<thead>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates select="row"/>
		<xsl:apply-templates select="tr[1]"/>
	</thead>
</xsl:template>

<xsl:template match="tfoot">
	<tfoot>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates select="row"/>
		<xsl:apply-templates select="tr[1]"/>
	</tfoot>
</xsl:template>

<xsl:template match="tbody">
	<tbody>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates select="row"/>
		<xsl:apply-templates select="tr[1]"/>
	</tbody>
</xsl:template>

<xsl:template match="row">
	<row>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates/>
	</row>
</xsl:template>

<xsl:template match="entry">
	<entry>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates/>
	</entry>
</xsl:template>

<xsl:template match="entrytbl">
	<entry/>
</xsl:template>

<xsl:template match="tr">
	<xsl:param name="row" select="1"/>
	<xsl:param name="empty-cells">
		<xsl:apply-templates select="*[1]" mode="build-empty-cells"/>
	</xsl:param>
	<row>
		<xsl:for-each select="@*">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:apply-templates select="*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col" select="1"/>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</row>
	<xsl:apply-templates select="following-sibling::tr[1]">
		<xsl:with-param name="row" select="$row + 1"/>
		<xsl:with-param name="empty-cells" select="$empty-cells"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template match="th|td">
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="empty-cells" select="/.."/>
	<entry>
		<xsl:for-each select="@align | @lang | @xreflabel | @valign | @width | @nowrap">
			<xsl:copy/>
		</xsl:for-each>
		<xsl:if test="@colspan &gt; 1">
			<xsl:call-template name="get-span-attributes">
				<xsl:with-param name="colspan" select="@colspan"/>
				<xsl:with-param name="col" select="$col"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="@rowspan &gt; 1">
			<xsl:attribute name="morerows" select="@rowspan - 1"/>
		</xsl:if>
		<!-- <xsl:text>\textit{</xsl:text>
		<xsl:value-of select="$row"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="$col"/>
		<xsl:text>} </xsl:text> -->
		<xsl:apply-templates/>
	</entry>
	<xsl:if test="following-sibling::*">
		<xsl:apply-templates select="following-sibling::*[1]">
			<xsl:with-param name="row" select="$row"/>
			<xsl:with-param name="col">
				<xsl:call-template name="get-next-col">
					<xsl:with-param name="row" select="$row"/>
					<xsl:with-param name="col">
						<xsl:choose>
							<xsl:when test="@colspan">
								<xsl:value-of select="$col + @colspan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$col + 1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
					<xsl:with-param name="empty-cells" select="$empty-cells"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="empty-cells" select="$empty-cells"/>
		</xsl:apply-templates>
	</xsl:if>
</xsl:template>

<xsl:template name="get-span-attributes">
	<xsl:param name="colspan"/>
	<xsl:param name="col"/>
	<xsl:attribute name="namest">
		<xsl:text>col</xsl:text>
		<xsl:value-of select="$col"/>
	</xsl:attribute>
	<xsl:attribute name="nameend">
		<xsl:text>col</xsl:text>
		<xsl:value-of select="$col + $colspan - 1"/>
	</xsl:attribute>
</xsl:template>

<xsl:template match="th|td" mode="build-empty-cells">
	<xsl:param name="row" select="1"/>
	<xsl:param name="col" select="1"/>
	<xsl:param name="empty-cells" select="/.."/>
	<xsl:variable name="cells">
		<xsl:choose>
			<xsl:when test="@rowspan and (@rowspan &gt; 1)">
				<xsl:perform-sort>
					<xsl:sort select="@row"/>
					<xsl:sort select="@col"/>
					<xsl:copy-of select="$empty-cells/*"/>
					<xsl:call-template name="build-empty-cells">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col" select="$col"/>
						<xsl:with-param name="cell" select="."/>
					</xsl:call-template>
				</xsl:perform-sort>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$empty-cells"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="following-sibling::*">
			<xsl:apply-templates select="following-sibling::*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row"/>
						<xsl:with-param name="col">
							<xsl:choose>
								<xsl:when test="@colspan">
									<xsl:value-of select="$col + @colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$col + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:when test="not(following-sibling::*) and (../following-sibling::tr)">
			<xsl:apply-templates select="../following-sibling::tr[1]/*[1]" mode="build-empty-cells">
				<xsl:with-param name="row" select="$row + 1"/>
				<xsl:with-param name="col">
					<xsl:call-template name="get-next-col">
						<xsl:with-param name="row" select="$row + 1"/>
						<xsl:with-param name="col" select="1"/>
						<xsl:with-param name="empty-cells" select="$cells"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="empty-cells" select="$cells"/>
			</xsl:apply-templates>
		</xsl:when>
		<xsl:otherwise>
			<xsl:copy-of select="$cells"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="build-empty-cells">
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="cell"/>
	<xsl:param name="n" select="1"/>
	<xsl:if test="$n &lt; $cell/@rowspan">
		<entry>
			<xsl:attribute name="row" select="$row + 1"/>
			<xsl:attribute name="col" select="$col"/>
			<xsl:if test="$cell/@colspan">
				<xsl:copy-of select="$cell/@colspan"/>
			</xsl:if>
		</entry>
		<xsl:call-template name="build-empty-cells">
			<xsl:with-param name="row" select="$row + 1"/>
			<xsl:with-param name="col" select="$col"/>
			<xsl:with-param name="cell" select="$cell"/>
			<xsl:with-param name="n" select="$n + 1"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template name="get-next-col">
	<xsl:param name="row"/>
	<xsl:param name="col"/>
	<xsl:param name="empty-cells"/>
	<xsl:choose>
		<xsl:when test="($row = 1) or not($empty-cells/entry[@row = $row])">
			<xsl:value-of select="$col"/>
		</xsl:when>
		<xsl:when test="$empty-cells/entry[@row = $row]">
			<xsl:variable name="is-cell-taken">
				<xsl:call-template name="is-cell-taken">
					<xsl:with-param name="col" select="$col"/>
					<xsl:with-param name="empty-cells">
						<xsl:copy-of select="$empty-cells/entry[@row = $row]"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$is-cell-taken = 0">
					<xsl:value-of select="$col"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="$col"/>
						<xsl:with-param name="empty-cells">
							<xsl:copy-of select="$empty-cells/entry[@row = $row]"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="is-cell-taken">
	<xsl:param name="col"/>
	<xsl:param name="empty-cells"/>
	<xsl:text>0</xsl:text>
	<xsl:for-each select="$empty-cells/entry">
		<xsl:if test="($col &gt;= @col) and ($col &lt; (@col + @colspan))">
			<xsl:text>1</xsl:text>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="get-next-column">
	<xsl:param name="col"/>
	<xsl:param name="takencol" select="0"/>
	<xsl:param name="empty-cells"/>
	<xsl:choose>
		<xsl:when test="empty($empty-cells)">
			<xsl:value-of select="$col"/>
		</xsl:when>
		<xsl:when test="$takencol = 0">
			<xsl:for-each select="$empty-cells/*">
				<xsl:if test="($col &gt;= @col) and ($col &lt; (@col + @colspan))">
					<xsl:variable name="colspan">
						<xsl:choose>
							<xsl:when test="@colspan">
								<xsl:value-of select="@colspan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:number value="1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="@col + $colspan"/>
						<xsl:with-param name="empty-cells" select="$empty-cells"/>
						<xsl:with-param name="takencol" select="@col"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
			<xsl:variable name="next-cell" select="$empty-cells/*[@col = $takencol]/following-sibling::*[1]"/>
			<xsl:variable name="colspan">
				<xsl:choose>
					<xsl:when test="$next-cell/@colspan">
						<xsl:value-of select="$next-cell/@colspan"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:number value="1"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="($col &gt;= $next-cell/@col) and ($col &lt; ($next-cell/@col + $next-cell/@colspan))">
					<xsl:call-template name="get-next-column">
						<xsl:with-param name="col" select="$next-cell/@col + $colspan"/>
						<xsl:with-param name="empty-cells" select="$empty-cells"/>
						<xsl:with-param name="takencol" select="$next-cell/@col"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$col"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Bloks kolonnu skaita iegūšanai - sākums -->
<xsl:template name="get_cols_number">
	<xsl:param name="entry" select="tbody/row[1]/*[1] | descendant::tr[not(th)][1]/td[1]"/>
	<xsl:param name="pos" select="0"/>
	<xsl:choose>
		<xsl:when test="$entry/self::entry or $entry/self::entrytbl">
			<xsl:choose>
				<xsl:when test="$entry/following-sibling::*">
					<xsl:call-template name="get_cols_number">
						<xsl:with-param name="entry" select="$entry/following-sibling::*[1]"/>
						<xsl:with-param name="pos">
							<xsl:choose>
								<xsl:when test="$entry/@spanname or ($entry/@namest and $entry/@nameend)">
									<xsl:variable name="colspan">
										<xsl:call-template name="get-colspan">
											<xsl:with-param name="entry" select="$entry"/>
										</xsl:call-template>
									</xsl:variable>
									<xsl:value-of select="$pos + $colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$pos + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$entry/@spanname or ($entry/@namest and $entry/@nameend)">
							<xsl:variable name="colspan">
								<xsl:call-template name="get-colspan">
									<xsl:with-param name="entry" select="$entry"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:value-of select="$pos + $colspan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="$entry/self::td">
			<xsl:choose>
				<xsl:when test="$entry/following-sibling::td">
					<xsl:call-template name="get_cols_number">
						<xsl:with-param name="entry" select="$entry/following-sibling::td[1]"/>
						<xsl:with-param name="pos">
							<xsl:choose>
								<xsl:when test="$entry/@colspan">
									<xsl:value-of select="$pos + $entry/@colspan"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$pos + 1"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$entry/@colspan">
							<xsl:value-of select="$pos + $entry/@colspan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$pos + 1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="get-colspan">
	<xsl:param name="entry"/>
	<xsl:choose>
		<xsl:when test="$entry/@spanname or ($entry/@namest and $entry/@nameend)">
			<xsl:variable name="namest">
				<xsl:choose>
					<xsl:when test="$entry/@spanname">
						<xsl:variable name="spanname" select="$entry/@spanname"/>
						<xsl:value-of select="//spanspec[@spanname=$spanname]/@namest"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$entry/@namest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="nameend">
				<xsl:choose>
					<xsl:when test="$entry/@spanname">
						<xsl:variable name="spanname" select="$entry/@spanname"/>
						<xsl:value-of select="//spanspec[@spanname=$spanname]/@nameend"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$entry/@nameend"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="stnum">
				<xsl:call-template name="get-colnum">
					<xsl:with-param name="id">
						<xsl:choose>
							<xsl:when test="$entry/../(parent::thead | parent::tfoot)/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($entry/../(parent::thead | parent::tfoot)/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$entry/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($entry/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$entry/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($entry/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:when test="$entry/../../parent::tgroup/tfoot/colspec[@colname=$namest]">
								<xsl:value-of select="generate-id($entry/../../parent::tgroup/tfoot/colspec[@colname=$namest])"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="generate-id($entry/(ancestor::table | ancestor::informaltable)//colspec[@colname=$namest])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="endnum">
				<xsl:call-template name="get-colnum">
					<xsl:with-param name="id">
						<xsl:choose>
							<xsl:when test="$entry/../(parent::thead | parent::tfoot)/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($entry/../(parent::thead | parent::tfoot)/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$entry/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($entry/../../(parent::tgroup | parent::entrytbl)/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$entry/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($entry/../../(parent::tgroup | parent::entrytbl)/thead/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:when test="$entry/../../parent::tgroup/tfoot/colspec[@colname=$nameend]">
								<xsl:value-of select="generate-id($entry/../../parent::tgroup/tfoot/colspec[@colname=$nameend])"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="generate-id($entry/(ancestor::table | ancestor::informaltable)//colspec[@colname=$nameend])"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:value-of select="$endnum - $stnum + 1"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>1</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="get-colnum">
	<xsl:param name="id"/>
	<xsl:param name="num" select="0"/>
	<xsl:choose>
		<xsl:when test="//colspec[generate-id(.)=$id]/@colnum">
			<xsl:value-of select="$num + //colspec[generate-id(.)=$id]/@colnum"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="not(//colspec[generate-id(.)=$id]/preceding-sibling::colspec)">
					<xsl:value-of select="$num + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="get-colnum">
						<xsl:with-param name="id" select="generate-id(//colspec[generate-id(.)=$id]/preceding-sibling::colspec[1])"/>
						<xsl:with-param name="num" select="$num + 1"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<!-- Bloks kolonnu skaita iegūšanai - beigas -->


</xsl:stylesheet>
